#include <kdialog.h>
#include <klocale.h>

/********************************************************************************
** Form generated from reading UI file 'kcmkttsmgrwidget.ui'
**
** Created by: Qt User Interface Compiler version 4.8.7
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KCMKTTSMGRWIDGET_H
#define UI_KCMKTTSMGRWIDGET_H

#include <QtCore/QVariant>
#include <QtGui/QAction>
#include <QtGui/QApplication>
#include <QtGui/QButtonGroup>
#include <QtGui/QCheckBox>
#include <QtGui/QGridLayout>
#include <QtGui/QHBoxLayout>
#include <QtGui/QHeaderView>
#include <QtGui/QLabel>
#include <QtGui/QSpacerItem>
#include <QtGui/QTreeView>
#include <QtGui/QVBoxLayout>
#include <QtGui/QWidget>
#include <klocale.h>
#include "kcmodule.h"
#include "kpushbutton.h"
#include "ktabwidget.h"

QT_BEGIN_NAMESPACE

class Ui_KCMKttsMgrWidget
{
public:
    QGridLayout *gridLayout;
    KTabWidget *mainTab;
    QWidget *tab;
    QGridLayout *gridLayout1;
    QLabel *kttsdVersion;
    QSpacerItem *spacerItem;
    QCheckBox *enableJovieCheckBox;
    QWidget *TabPage;
    QGridLayout *gridLayout2;
    QVBoxLayout *vboxLayout;
    KPushButton *addTalkerButton;
    KPushButton *higherTalkerPriorityButton;
    KPushButton *lowerTalkerPriorityButton;
    KPushButton *configureTalkerButton;
    KPushButton *removeTalkerButton;
    QSpacerItem *spacerItem1;
    QTreeView *talkersView;
    QWidget *TabPage1;
    QGridLayout *gridLayout3;
    QHBoxLayout *hboxLayout;
    QTreeView *filtersView;
    QVBoxLayout *vboxLayout1;
    KPushButton *addFilterButton;
    KPushButton *higherFilterPriorityButton;
    KPushButton *lowerFilterPriorityButton;
    KPushButton *configureFilterButton;
    KPushButton *removeFilterButton;
    QSpacerItem *spacerItem2;

    void setupUi(KCModule *KCMKttsMgrWidget)
    {
        if (KCMKttsMgrWidget->objectName().isEmpty())
            KCMKttsMgrWidget->setObjectName(QString::fromUtf8("KCMKttsMgrWidget"));
        KCMKttsMgrWidget->resize(443, 261);
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(KCMKttsMgrWidget->sizePolicy().hasHeightForWidth());
        KCMKttsMgrWidget->setSizePolicy(sizePolicy);
        gridLayout = new QGridLayout(KCMKttsMgrWidget);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        mainTab = new KTabWidget(KCMKttsMgrWidget);
        mainTab->setObjectName(QString::fromUtf8("mainTab"));
        sizePolicy.setHeightForWidth(mainTab->sizePolicy().hasHeightForWidth());
        mainTab->setSizePolicy(sizePolicy);
        tab = new QWidget();
        tab->setObjectName(QString::fromUtf8("tab"));
        gridLayout1 = new QGridLayout(tab);
        gridLayout1->setObjectName(QString::fromUtf8("gridLayout1"));
        kttsdVersion = new QLabel(tab);
        kttsdVersion->setObjectName(QString::fromUtf8("kttsdVersion"));

        gridLayout1->addWidget(kttsdVersion, 2, 0, 1, 1);

        spacerItem = new QSpacerItem(0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout1->addItem(spacerItem, 1, 0, 1, 1);

        enableJovieCheckBox = new QCheckBox(tab);
        enableJovieCheckBox->setObjectName(QString::fromUtf8("enableJovieCheckBox"));

        gridLayout1->addWidget(enableJovieCheckBox, 0, 0, 1, 1);

        mainTab->addTab(tab, QString());
        TabPage = new QWidget();
        TabPage->setObjectName(QString::fromUtf8("TabPage"));
        gridLayout2 = new QGridLayout(TabPage);
        gridLayout2->setObjectName(QString::fromUtf8("gridLayout2"));
        vboxLayout = new QVBoxLayout();
        vboxLayout->setObjectName(QString::fromUtf8("vboxLayout"));
        addTalkerButton = new KPushButton(TabPage);
        addTalkerButton->setObjectName(QString::fromUtf8("addTalkerButton"));
        QSizePolicy sizePolicy1(QSizePolicy::Minimum, QSizePolicy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(addTalkerButton->sizePolicy().hasHeightForWidth());
        addTalkerButton->setSizePolicy(sizePolicy1);

        vboxLayout->addWidget(addTalkerButton);

        higherTalkerPriorityButton = new KPushButton(TabPage);
        higherTalkerPriorityButton->setObjectName(QString::fromUtf8("higherTalkerPriorityButton"));
        QSizePolicy sizePolicy2(QSizePolicy::Preferred, QSizePolicy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(higherTalkerPriorityButton->sizePolicy().hasHeightForWidth());
        higherTalkerPriorityButton->setSizePolicy(sizePolicy2);

        vboxLayout->addWidget(higherTalkerPriorityButton);

        lowerTalkerPriorityButton = new KPushButton(TabPage);
        lowerTalkerPriorityButton->setObjectName(QString::fromUtf8("lowerTalkerPriorityButton"));
        sizePolicy2.setHeightForWidth(lowerTalkerPriorityButton->sizePolicy().hasHeightForWidth());
        lowerTalkerPriorityButton->setSizePolicy(sizePolicy2);

        vboxLayout->addWidget(lowerTalkerPriorityButton);

        configureTalkerButton = new KPushButton(TabPage);
        configureTalkerButton->setObjectName(QString::fromUtf8("configureTalkerButton"));
        configureTalkerButton->setEnabled(false);
        sizePolicy1.setHeightForWidth(configureTalkerButton->sizePolicy().hasHeightForWidth());
        configureTalkerButton->setSizePolicy(sizePolicy1);

        vboxLayout->addWidget(configureTalkerButton);

        removeTalkerButton = new KPushButton(TabPage);
        removeTalkerButton->setObjectName(QString::fromUtf8("removeTalkerButton"));
        removeTalkerButton->setEnabled(false);
        sizePolicy1.setHeightForWidth(removeTalkerButton->sizePolicy().hasHeightForWidth());
        removeTalkerButton->setSizePolicy(sizePolicy1);

        vboxLayout->addWidget(removeTalkerButton);

        spacerItem1 = new QSpacerItem(0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);

        vboxLayout->addItem(spacerItem1);


        gridLayout2->addLayout(vboxLayout, 0, 1, 1, 1);

        talkersView = new QTreeView(TabPage);
        talkersView->setObjectName(QString::fromUtf8("talkersView"));

        gridLayout2->addWidget(talkersView, 0, 0, 1, 1);

        mainTab->addTab(TabPage, QString());
        TabPage1 = new QWidget();
        TabPage1->setObjectName(QString::fromUtf8("TabPage1"));
        gridLayout3 = new QGridLayout(TabPage1);
        gridLayout3->setObjectName(QString::fromUtf8("gridLayout3"));
        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName(QString::fromUtf8("hboxLayout"));
        filtersView = new QTreeView(TabPage1);
        filtersView->setObjectName(QString::fromUtf8("filtersView"));

        hboxLayout->addWidget(filtersView);

        vboxLayout1 = new QVBoxLayout();
        vboxLayout1->setObjectName(QString::fromUtf8("vboxLayout1"));
        addFilterButton = new KPushButton(TabPage1);
        addFilterButton->setObjectName(QString::fromUtf8("addFilterButton"));
        sizePolicy1.setHeightForWidth(addFilterButton->sizePolicy().hasHeightForWidth());
        addFilterButton->setSizePolicy(sizePolicy1);

        vboxLayout1->addWidget(addFilterButton);

        higherFilterPriorityButton = new KPushButton(TabPage1);
        higherFilterPriorityButton->setObjectName(QString::fromUtf8("higherFilterPriorityButton"));
        sizePolicy2.setHeightForWidth(higherFilterPriorityButton->sizePolicy().hasHeightForWidth());
        higherFilterPriorityButton->setSizePolicy(sizePolicy2);

        vboxLayout1->addWidget(higherFilterPriorityButton);

        lowerFilterPriorityButton = new KPushButton(TabPage1);
        lowerFilterPriorityButton->setObjectName(QString::fromUtf8("lowerFilterPriorityButton"));
        sizePolicy2.setHeightForWidth(lowerFilterPriorityButton->sizePolicy().hasHeightForWidth());
        lowerFilterPriorityButton->setSizePolicy(sizePolicy2);

        vboxLayout1->addWidget(lowerFilterPriorityButton);

        configureFilterButton = new KPushButton(TabPage1);
        configureFilterButton->setObjectName(QString::fromUtf8("configureFilterButton"));
        configureFilterButton->setEnabled(false);
        sizePolicy1.setHeightForWidth(configureFilterButton->sizePolicy().hasHeightForWidth());
        configureFilterButton->setSizePolicy(sizePolicy1);

        vboxLayout1->addWidget(configureFilterButton);

        removeFilterButton = new KPushButton(TabPage1);
        removeFilterButton->setObjectName(QString::fromUtf8("removeFilterButton"));
        removeFilterButton->setEnabled(false);
        sizePolicy1.setHeightForWidth(removeFilterButton->sizePolicy().hasHeightForWidth());
        removeFilterButton->setSizePolicy(sizePolicy1);

        vboxLayout1->addWidget(removeFilterButton);

        spacerItem2 = new QSpacerItem(0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);

        vboxLayout1->addItem(spacerItem2);


        hboxLayout->addLayout(vboxLayout1);


        gridLayout3->addLayout(hboxLayout, 0, 0, 1, 1);

        mainTab->addTab(TabPage1, QString());

        gridLayout->addWidget(mainTab, 0, 0, 1, 1);

        QWidget::setTabOrder(mainTab, enableJovieCheckBox);
        QWidget::setTabOrder(enableJovieCheckBox, addTalkerButton);
        QWidget::setTabOrder(addTalkerButton, higherTalkerPriorityButton);
        QWidget::setTabOrder(higherTalkerPriorityButton, lowerTalkerPriorityButton);
        QWidget::setTabOrder(lowerTalkerPriorityButton, configureTalkerButton);
        QWidget::setTabOrder(configureTalkerButton, removeTalkerButton);
        QWidget::setTabOrder(removeTalkerButton, addFilterButton);
        QWidget::setTabOrder(addFilterButton, higherFilterPriorityButton);
        QWidget::setTabOrder(higherFilterPriorityButton, lowerFilterPriorityButton);
        QWidget::setTabOrder(lowerFilterPriorityButton, configureFilterButton);
        QWidget::setTabOrder(configureFilterButton, removeFilterButton);

        retranslateUi(KCMKttsMgrWidget);

        mainTab->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(KCMKttsMgrWidget);
    } // setupUi

    void retranslateUi(KCModule *KCMKttsMgrWidget)
    {
        kttsdVersion->setText(tr2i18n("Jovie not running", 0));
#ifndef UI_QT_NO_WHATSTHIS
        enableJovieCheckBox->setWhatsThis(tr2i18n("Check to start the Jovie Daemon and enable Text-to-Speech.", 0));
#endif // QT_NO_WHATSTHIS
        enableJovieCheckBox->setText(tr2i18n("&Enable Text-to-Speech System (Jovie)", 0));
        mainTab->setTabText(mainTab->indexOf(tab), tr2i18n("General", "General, as title of window"));
#ifndef UI_QT_NO_WHATSTHIS
        addTalkerButton->setWhatsThis(tr2i18n("Click to add and configure a new Talker (speech synthesizer).", 0));
#endif // QT_NO_WHATSTHIS
        addTalkerButton->setText(tr2i18n("Add...", 0));
        higherTalkerPriorityButton->setText(tr2i18n("U&p", 0));
        lowerTalkerPriorityButton->setText(tr2i18n("Do&wn", 0));
#ifndef UI_QT_NO_WHATSTHIS
        configureTalkerButton->setWhatsThis(tr2i18n("Click to configure options for the highlighted Talker.", 0));
#endif // QT_NO_WHATSTHIS
        configureTalkerButton->setText(tr2i18n("&Edit...", 0));
#ifndef UI_QT_NO_WHATSTHIS
        removeTalkerButton->setWhatsThis(tr2i18n("Click to remove the highlighted Talker.", 0));
#endif // QT_NO_WHATSTHIS
        removeTalkerButton->setText(tr2i18n("&Remove", 0));
        mainTab->setTabText(mainTab->indexOf(TabPage), tr2i18n("Talkers", 0));
#ifndef UI_QT_NO_WHATSTHIS
        addFilterButton->setWhatsThis(tr2i18n("Click to add and configure a new Filter.", 0));
#endif // QT_NO_WHATSTHIS
        addFilterButton->setText(tr2i18n("Add...", 0));
#ifndef UI_QT_NO_WHATSTHIS
        higherFilterPriorityButton->setWhatsThis(tr2i18n("Click to move selected filter up in the list.  Filters higher in the list are applied first.", 0));
#endif // QT_NO_WHATSTHIS
        higherFilterPriorityButton->setText(tr2i18n("U&p", 0));
#ifndef UI_QT_NO_WHATSTHIS
        lowerFilterPriorityButton->setWhatsThis(tr2i18n("Click to move a filter down in the list.  Filters lower in the list are applied last.", 0));
#endif // QT_NO_WHATSTHIS
        lowerFilterPriorityButton->setText(tr2i18n("Do&wn", 0));
#ifndef UI_QT_NO_WHATSTHIS
        configureFilterButton->setWhatsThis(tr2i18n("Click to configure options for the highlighted Filter.", 0));
#endif // QT_NO_WHATSTHIS
        configureFilterButton->setText(tr2i18n("&Edit...", 0));
#ifndef UI_QT_NO_WHATSTHIS
        removeFilterButton->setWhatsThis(tr2i18n("Click to remove the highlighted Filter.", 0));
#endif // QT_NO_WHATSTHIS
        removeFilterButton->setText(tr2i18n("&Remove", 0));
        mainTab->setTabText(mainTab->indexOf(TabPage1), tr2i18n("Filters", 0));
        Q_UNUSED(KCMKttsMgrWidget);
    } // retranslateUi

};

namespace Ui {
    class KCMKttsMgrWidget: public Ui_KCMKttsMgrWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // KCMKTTSMGRWIDGET_H

