#include <kdialog.h>
#include <klocale.h>

/********************************************************************************
** Form generated from reading UI file 'editreplacementwidget.ui'
**
** Created by: Qt User Interface Compiler version 4.8.7
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_EDITREPLACEMENTWIDGET_H
#define UI_EDITREPLACEMENTWIDGET_H

#include <QtCore/QVariant>
#include <QtGui/QAction>
#include <QtGui/QApplication>
#include <QtGui/QButtonGroup>
#include <QtGui/QCheckBox>
#include <QtGui/QGridLayout>
#include <QtGui/QGroupBox>
#include <QtGui/QHBoxLayout>
#include <QtGui/QHeaderView>
#include <QtGui/QLabel>
#include <QtGui/QRadioButton>
#include <QtGui/QVBoxLayout>
#include <QtGui/QWidget>
#include "klineedit.h"
#include "kpushbutton.h"

QT_BEGIN_NAMESPACE

class Ui_EditReplacementWidget
{
public:
    QGridLayout *gridLayout;
    QGroupBox *typeGroupBox;
    QVBoxLayout *vboxLayout;
    QRadioButton *wordRadioButton;
    QRadioButton *regexpRadioButton;
    QVBoxLayout *vboxLayout1;
    QLabel *matchLabel;
    QLabel *substLabel;
    QVBoxLayout *vboxLayout2;
    QHBoxLayout *hboxLayout;
    KLineEdit *matchLineEdit;
    KPushButton *matchButton;
    KLineEdit *substLineEdit;
    QCheckBox *matchCaseCheckBox;

    void setupUi(QWidget *EditReplacementWidget)
    {
        if (EditReplacementWidget->objectName().isEmpty())
            EditReplacementWidget->setObjectName(QString::fromUtf8("EditReplacementWidget"));
        EditReplacementWidget->resize(364, 163);
        gridLayout = new QGridLayout(EditReplacementWidget);
#ifndef UI_Q_OS_MAC
        gridLayout->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        gridLayout->setContentsMargins(9, 9, 9, 9);
#endif
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        typeGroupBox = new QGroupBox(EditReplacementWidget);
        typeGroupBox->setObjectName(QString::fromUtf8("typeGroupBox"));
        vboxLayout = new QVBoxLayout(typeGroupBox);
#ifndef UI_Q_OS_MAC
        vboxLayout->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        vboxLayout->setContentsMargins(9, 9, 9, 9);
#endif
        vboxLayout->setObjectName(QString::fromUtf8("vboxLayout"));
        wordRadioButton = new QRadioButton(typeGroupBox);
        wordRadioButton->setObjectName(QString::fromUtf8("wordRadioButton"));
        wordRadioButton->setChecked(true);

        vboxLayout->addWidget(wordRadioButton);

        regexpRadioButton = new QRadioButton(typeGroupBox);
        regexpRadioButton->setObjectName(QString::fromUtf8("regexpRadioButton"));

        vboxLayout->addWidget(regexpRadioButton);


        gridLayout->addWidget(typeGroupBox, 0, 0, 1, 2);

        vboxLayout1 = new QVBoxLayout();
#ifndef UI_Q_OS_MAC
        vboxLayout1->setSpacing(6);
#endif
        vboxLayout1->setContentsMargins(0, 0, 0, 0);
        vboxLayout1->setObjectName(QString::fromUtf8("vboxLayout1"));
        matchLabel = new QLabel(EditReplacementWidget);
        matchLabel->setObjectName(QString::fromUtf8("matchLabel"));
        matchLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        vboxLayout1->addWidget(matchLabel);

        substLabel = new QLabel(EditReplacementWidget);
        substLabel->setObjectName(QString::fromUtf8("substLabel"));
        substLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        vboxLayout1->addWidget(substLabel);


        gridLayout->addLayout(vboxLayout1, 1, 0, 1, 1);

        vboxLayout2 = new QVBoxLayout();
#ifndef UI_Q_OS_MAC
        vboxLayout2->setSpacing(6);
#endif
        vboxLayout2->setContentsMargins(0, 0, 0, 0);
        vboxLayout2->setObjectName(QString::fromUtf8("vboxLayout2"));
        hboxLayout = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        hboxLayout->setContentsMargins(0, 0, 0, 0);
#endif
        hboxLayout->setObjectName(QString::fromUtf8("hboxLayout"));
        matchLineEdit = new KLineEdit(EditReplacementWidget);
        matchLineEdit->setObjectName(QString::fromUtf8("matchLineEdit"));
        QSizePolicy sizePolicy(static_cast<QSizePolicy::Policy>(7), static_cast<QSizePolicy::Policy>(7));
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(matchLineEdit->sizePolicy().hasHeightForWidth());
        matchLineEdit->setSizePolicy(sizePolicy);

        hboxLayout->addWidget(matchLineEdit);

        matchButton = new KPushButton(EditReplacementWidget);
        matchButton->setObjectName(QString::fromUtf8("matchButton"));

        hboxLayout->addWidget(matchButton);


        vboxLayout2->addLayout(hboxLayout);

        substLineEdit = new KLineEdit(EditReplacementWidget);
        substLineEdit->setObjectName(QString::fromUtf8("substLineEdit"));

        vboxLayout2->addWidget(substLineEdit);


        gridLayout->addLayout(vboxLayout2, 1, 1, 1, 2);

        matchCaseCheckBox = new QCheckBox(EditReplacementWidget);
        matchCaseCheckBox->setObjectName(QString::fromUtf8("matchCaseCheckBox"));

        gridLayout->addWidget(matchCaseCheckBox, 0, 2, 1, 1);

#ifndef UI_QT_NO_SHORTCUT
        matchLabel->setBuddy(matchLineEdit);
        substLabel->setBuddy(substLineEdit);
#endif // QT_NO_SHORTCUT

        retranslateUi(EditReplacementWidget);

        QMetaObject::connectSlotsByName(EditReplacementWidget);
    } // setupUi

    void retranslateUi(QWidget *EditReplacementWidget)
    {
        typeGroupBox->setTitle(tr2i18n("&Type", 0));
        wordRadioButton->setText(tr2i18n("&Word", 0));
        regexpRadioButton->setText(tr2i18n("Regular &expression", 0));
        matchLabel->setText(tr2i18n("&Match:", 0));
        substLabel->setText(tr2i18n("&Replace with:", 0));
        matchButton->setText(tr2i18n("...", 0));
        matchCaseCheckBox->setText(tr2i18n("Match &case", 0));
        Q_UNUSED(EditReplacementWidget);
    } // retranslateUi

};

namespace Ui {
    class EditReplacementWidget: public Ui_EditReplacementWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // EDITREPLACEMENTWIDGET_H

