#include <kdialog.h>
#include <klocale.h>

/*
Widget for configuring String Replacer Filter for KTTSD.
*/

/********************************************************************************
** Form generated from reading UI file 'stringreplacerconfwidget.ui'
**
** Created by: Qt User Interface Compiler version 4.8.7
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_STRINGREPLACERCONFWIDGET_H
#define UI_STRINGREPLACERCONFWIDGET_H

#include <QtCore/QVariant>
#include <QtGui/QAction>
#include <QtGui/QApplication>
#include <QtGui/QButtonGroup>
#include <QtGui/QGridLayout>
#include <QtGui/QGroupBox>
#include <QtGui/QHBoxLayout>
#include <QtGui/QHeaderView>
#include <QtGui/QLabel>
#include <QtGui/QPushButton>
#include <QtGui/QSpacerItem>
#include <QtGui/QTableWidget>
#include <QtGui/QVBoxLayout>
#include <QtGui/QWidget>
#include "klineedit.h"
#include "kpushbutton.h"

QT_BEGIN_NAMESPACE

class Ui_StringReplacerConfWidget
{
public:
    QGridLayout *gridLayout;
    QHBoxLayout *hboxLayout;
    QLabel *nameLabel;
    KLineEdit *nameLineEdit;
    QGroupBox *applyGroupBox;
    QGridLayout *gridLayout1;
    QVBoxLayout *vboxLayout;
    QLabel *languageLabel;
    QLabel *appIdLabel;
    QVBoxLayout *vboxLayout1;
    QHBoxLayout *hboxLayout1;
    KLineEdit *languageLineEdit;
    KPushButton *languageBrowseButton;
    KLineEdit *appIdLineEdit;
    QHBoxLayout *hboxLayout2;
    KPushButton *loadButton;
    KPushButton *saveButton;
    KPushButton *clearButton;
    QGridLayout *gridLayout2;
    QVBoxLayout *vboxLayout2;
    KPushButton *addButton;
    QPushButton *upButton;
    QPushButton *downButton;
    KPushButton *editButton;
    KPushButton *removeButton;
    QSpacerItem *spacerItem;
    QTableWidget *substLView;

    void setupUi(QWidget *StringReplacerConfWidget)
    {
        if (StringReplacerConfWidget->objectName().isEmpty())
            StringReplacerConfWidget->setObjectName(QString::fromUtf8("StringReplacerConfWidget"));
        StringReplacerConfWidget->resize(548, 421);
        gridLayout = new QGridLayout(StringReplacerConfWidget);
#ifndef UI_Q_OS_MAC
        gridLayout->setSpacing(6);
#endif
        gridLayout->setContentsMargins(11, 11, 11, 11);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        hboxLayout = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        hboxLayout->setContentsMargins(0, 0, 0, 0);
#endif
        hboxLayout->setObjectName(QString::fromUtf8("hboxLayout"));
        nameLabel = new QLabel(StringReplacerConfWidget);
        nameLabel->setObjectName(QString::fromUtf8("nameLabel"));
        nameLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        hboxLayout->addWidget(nameLabel);

        nameLineEdit = new KLineEdit(StringReplacerConfWidget);
        nameLineEdit->setObjectName(QString::fromUtf8("nameLineEdit"));

        hboxLayout->addWidget(nameLineEdit);


        gridLayout->addLayout(hboxLayout, 0, 0, 1, 1);

        applyGroupBox = new QGroupBox(StringReplacerConfWidget);
        applyGroupBox->setObjectName(QString::fromUtf8("applyGroupBox"));
        gridLayout1 = new QGridLayout(applyGroupBox);
#ifndef UI_Q_OS_MAC
        gridLayout1->setSpacing(6);
#endif
        gridLayout1->setContentsMargins(11, 11, 11, 11);
        gridLayout1->setObjectName(QString::fromUtf8("gridLayout1"));
        vboxLayout = new QVBoxLayout();
#ifndef UI_Q_OS_MAC
        vboxLayout->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        vboxLayout->setContentsMargins(0, 0, 0, 0);
#endif
        vboxLayout->setObjectName(QString::fromUtf8("vboxLayout"));
        languageLabel = new QLabel(applyGroupBox);
        languageLabel->setObjectName(QString::fromUtf8("languageLabel"));
        languageLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        vboxLayout->addWidget(languageLabel);

        appIdLabel = new QLabel(applyGroupBox);
        appIdLabel->setObjectName(QString::fromUtf8("appIdLabel"));
        appIdLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        vboxLayout->addWidget(appIdLabel);


        gridLayout1->addLayout(vboxLayout, 0, 0, 1, 1);

        vboxLayout1 = new QVBoxLayout();
#ifndef UI_Q_OS_MAC
        vboxLayout1->setSpacing(6);
#endif
        vboxLayout1->setContentsMargins(0, 0, 0, 0);
        vboxLayout1->setObjectName(QString::fromUtf8("vboxLayout1"));
        hboxLayout1 = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout1->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        hboxLayout1->setContentsMargins(0, 0, 0, 0);
#endif
        hboxLayout1->setObjectName(QString::fromUtf8("hboxLayout1"));
        languageLineEdit = new KLineEdit(applyGroupBox);
        languageLineEdit->setObjectName(QString::fromUtf8("languageLineEdit"));
        languageLineEdit->setEnabled(false);

        hboxLayout1->addWidget(languageLineEdit);

        languageBrowseButton = new KPushButton(applyGroupBox);
        languageBrowseButton->setObjectName(QString::fromUtf8("languageBrowseButton"));

        hboxLayout1->addWidget(languageBrowseButton);


        vboxLayout1->addLayout(hboxLayout1);

        appIdLineEdit = new KLineEdit(applyGroupBox);
        appIdLineEdit->setObjectName(QString::fromUtf8("appIdLineEdit"));

        vboxLayout1->addWidget(appIdLineEdit);


        gridLayout1->addLayout(vboxLayout1, 0, 1, 1, 1);


        gridLayout->addWidget(applyGroupBox, 3, 0, 1, 1);

        hboxLayout2 = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout2->setSpacing(6);
#endif
        hboxLayout2->setContentsMargins(0, 0, 0, 0);
        hboxLayout2->setObjectName(QString::fromUtf8("hboxLayout2"));
        loadButton = new KPushButton(StringReplacerConfWidget);
        loadButton->setObjectName(QString::fromUtf8("loadButton"));
        QSizePolicy sizePolicy(static_cast<QSizePolicy::Policy>(1), static_cast<QSizePolicy::Policy>(0));
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(loadButton->sizePolicy().hasHeightForWidth());
        loadButton->setSizePolicy(sizePolicy);

        hboxLayout2->addWidget(loadButton);

        saveButton = new KPushButton(StringReplacerConfWidget);
        saveButton->setObjectName(QString::fromUtf8("saveButton"));
        sizePolicy.setHeightForWidth(saveButton->sizePolicy().hasHeightForWidth());
        saveButton->setSizePolicy(sizePolicy);

        hboxLayout2->addWidget(saveButton);

        clearButton = new KPushButton(StringReplacerConfWidget);
        clearButton->setObjectName(QString::fromUtf8("clearButton"));
        sizePolicy.setHeightForWidth(clearButton->sizePolicy().hasHeightForWidth());
        clearButton->setSizePolicy(sizePolicy);

        hboxLayout2->addWidget(clearButton);


        gridLayout->addLayout(hboxLayout2, 2, 0, 1, 1);

        gridLayout2 = new QGridLayout();
#ifndef UI_Q_OS_MAC
        gridLayout2->setSpacing(6);
#endif
        gridLayout2->setContentsMargins(0, 0, 0, 0);
        gridLayout2->setObjectName(QString::fromUtf8("gridLayout2"));
        vboxLayout2 = new QVBoxLayout();
#ifndef UI_Q_OS_MAC
        vboxLayout2->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        vboxLayout2->setContentsMargins(0, 0, 0, 0);
#endif
        vboxLayout2->setObjectName(QString::fromUtf8("vboxLayout2"));
        addButton = new KPushButton(StringReplacerConfWidget);
        addButton->setObjectName(QString::fromUtf8("addButton"));
        sizePolicy.setHeightForWidth(addButton->sizePolicy().hasHeightForWidth());
        addButton->setSizePolicy(sizePolicy);

        vboxLayout2->addWidget(addButton);

        upButton = new QPushButton(StringReplacerConfWidget);
        upButton->setObjectName(QString::fromUtf8("upButton"));
        QSizePolicy sizePolicy1(static_cast<QSizePolicy::Policy>(5), static_cast<QSizePolicy::Policy>(0));
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(upButton->sizePolicy().hasHeightForWidth());
        upButton->setSizePolicy(sizePolicy1);

        vboxLayout2->addWidget(upButton);

        downButton = new QPushButton(StringReplacerConfWidget);
        downButton->setObjectName(QString::fromUtf8("downButton"));
        sizePolicy1.setHeightForWidth(downButton->sizePolicy().hasHeightForWidth());
        downButton->setSizePolicy(sizePolicy1);

        vboxLayout2->addWidget(downButton);

        editButton = new KPushButton(StringReplacerConfWidget);
        editButton->setObjectName(QString::fromUtf8("editButton"));
        editButton->setEnabled(false);
        sizePolicy.setHeightForWidth(editButton->sizePolicy().hasHeightForWidth());
        editButton->setSizePolicy(sizePolicy);

        vboxLayout2->addWidget(editButton);

        removeButton = new KPushButton(StringReplacerConfWidget);
        removeButton->setObjectName(QString::fromUtf8("removeButton"));
        removeButton->setEnabled(false);
        sizePolicy.setHeightForWidth(removeButton->sizePolicy().hasHeightForWidth());
        removeButton->setSizePolicy(sizePolicy);

        vboxLayout2->addWidget(removeButton);

        spacerItem = new QSpacerItem(20, 20, QSizePolicy::Minimum, QSizePolicy::Expanding);

        vboxLayout2->addItem(spacerItem);


        gridLayout2->addLayout(vboxLayout2, 0, 1, 1, 1);

        substLView = new QTableWidget(StringReplacerConfWidget);
        if (substLView->columnCount() < 4)
            substLView->setColumnCount(4);
        QTableWidgetItem *__qtablewidgetitem = new QTableWidgetItem();
        substLView->setHorizontalHeaderItem(0, __qtablewidgetitem);
        QTableWidgetItem *__qtablewidgetitem1 = new QTableWidgetItem();
        substLView->setHorizontalHeaderItem(1, __qtablewidgetitem1);
        QTableWidgetItem *__qtablewidgetitem2 = new QTableWidgetItem();
        substLView->setHorizontalHeaderItem(2, __qtablewidgetitem2);
        QTableWidgetItem *__qtablewidgetitem3 = new QTableWidgetItem();
        substLView->setHorizontalHeaderItem(3, __qtablewidgetitem3);
        substLView->setObjectName(QString::fromUtf8("substLView"));
        substLView->setEditTriggers(QAbstractItemView::NoEditTriggers);
        substLView->setSelectionMode(QAbstractItemView::SingleSelection);
        substLView->setSelectionBehavior(QAbstractItemView::SelectRows);
        substLView->setColumnCount(4);

        gridLayout2->addWidget(substLView, 0, 0, 1, 1);


        gridLayout->addLayout(gridLayout2, 1, 0, 1, 1);

#ifndef UI_QT_NO_SHORTCUT
        nameLabel->setBuddy(nameLineEdit);
        languageLabel->setBuddy(languageLineEdit);
        appIdLabel->setBuddy(appIdLineEdit);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(nameLineEdit, addButton);
        QWidget::setTabOrder(addButton, upButton);
        QWidget::setTabOrder(upButton, downButton);
        QWidget::setTabOrder(downButton, editButton);
        QWidget::setTabOrder(editButton, removeButton);
        QWidget::setTabOrder(removeButton, loadButton);
        QWidget::setTabOrder(loadButton, saveButton);
        QWidget::setTabOrder(saveButton, clearButton);
        QWidget::setTabOrder(clearButton, languageLineEdit);
        QWidget::setTabOrder(languageLineEdit, languageBrowseButton);
        QWidget::setTabOrder(languageBrowseButton, appIdLineEdit);

        retranslateUi(StringReplacerConfWidget);

        QMetaObject::connectSlotsByName(StringReplacerConfWidget);
    } // setupUi

    void retranslateUi(QWidget *StringReplacerConfWidget)
    {
        StringReplacerConfWidget->setWindowTitle(tr2i18n("Configure String Replacer", 0));
#ifndef UI_QT_NO_WHATSTHIS
        nameLabel->setWhatsThis(tr2i18n("Enter any name you like for this filter.", "What's this text"));
#endif // QT_NO_WHATSTHIS
        nameLabel->setText(tr2i18n("&Name:", 0));
#ifndef UI_QT_NO_WHATSTHIS
        nameLineEdit->setWhatsThis(tr2i18n("Enter any name you like for this filter.", 0));
#endif // QT_NO_WHATSTHIS
#ifndef UI_QT_NO_WHATSTHIS
        applyGroupBox->setWhatsThis(tr2i18n("These settings determines when the filter is applied to text.", 0));
#endif // QT_NO_WHATSTHIS
#ifndef UI_QT_NO_WHATSTHIS
        languageLabel->setWhatsThis(tr2i18n("This filter is applied to text jobs of the specified language.  You may select more than one language by clicking the browse button and Ctrl-clicking on more than one in the list.  If blank the filter applies to all text jobs of any language.", "What's this text"));
#endif // QT_NO_WHATSTHIS
        languageLabel->setText(tr2i18n("Lan&guage is:", 0));
#ifndef UI_QT_NO_WHATSTHIS
        appIdLabel->setWhatsThis(tr2i18n("Enter a D-Bus Application ID.  This filter will only apply to text jobs queued by that application.  You may enter more than one ID separated by commas.  If blank, this filter applies to text jobs queued by all applications.  Tip: Use kdcop from the command line to get the Application IDs of running applications.  Example: \"konversation, kvirc,ksirc,kopete\"", 0));
#endif // QT_NO_WHATSTHIS
        appIdLabel->setText(tr2i18n("Application &ID contains:", 0));
#ifndef UI_QT_NO_WHATSTHIS
        languageLineEdit->setWhatsThis(tr2i18n("This filter is applied to text jobs of the specified language.  You may select more than one language by clicking the browse button and Ctrl-clicking on more than one in the list.  If blank the filter applies to all text jobs of any language.", 0));
#endif // QT_NO_WHATSTHIS
#ifndef UI_QT_NO_WHATSTHIS
        languageBrowseButton->setWhatsThis(tr2i18n("Click to select one or more languages.  This filter will be applied to text jobs of those languages.", 0));
#endif // QT_NO_WHATSTHIS
        languageBrowseButton->setText(tr2i18n("...", 0));
#ifndef UI_QT_NO_WHATSTHIS
        appIdLineEdit->setWhatsThis(tr2i18n("<qt>Enter a D-Bus Application ID.  This filter will only apply to text jobs queued by that application.  You may enter more than one ID separated by commas.  Use <b>knotify</b> to match all messages sent as KDE notifications.  If blank, this filter applies to text jobs queued by all applications.  Tip: Use kdcop from the command line to get the Application IDs of running applications.  Example: \"konversation, kvirc,ksirc,kopete\"</qt>", 0));
#endif // QT_NO_WHATSTHIS
#ifndef UI_QT_NO_WHATSTHIS
        loadButton->setWhatsThis(tr2i18n("Click to load a word list from a file.", 0));
#endif // QT_NO_WHATSTHIS
        loadButton->setText(tr2i18n("Load", "Load a word list from a file"));
#ifndef UI_QT_NO_WHATSTHIS
        saveButton->setWhatsThis(tr2i18n("Click to save word list to a file.", 0));
#endif // QT_NO_WHATSTHIS
        saveButton->setText(tr2i18n("&Save", 0));
#ifndef UI_QT_NO_WHATSTHIS
        clearButton->setWhatsThis(tr2i18n("Click to empty the word list.", 0));
#endif // QT_NO_WHATSTHIS
        clearButton->setText(tr2i18n("Clear", "Clear the word list"));
#ifndef UI_QT_NO_WHATSTHIS
        addButton->setWhatsThis(tr2i18n("Click to add another word or regular expression to the list.", 0));
#endif // QT_NO_WHATSTHIS
        addButton->setText(tr2i18n("&Add", 0));
#ifndef UI_QT_NO_WHATSTHIS
        upButton->setWhatsThis(tr2i18n("Click to move selected word up in the list.  Words higher in the list are applied first.", 0));
#endif // QT_NO_WHATSTHIS
        upButton->setText(tr2i18n("&Up", 0));
#ifndef UI_QT_NO_WHATSTHIS
        downButton->setWhatsThis(tr2i18n("Click to move a word down in the list.  Words lower in the list are applied last.", 0));
#endif // QT_NO_WHATSTHIS
        downButton->setText(tr2i18n("Do&wn", 0));
#ifndef UI_QT_NO_WHATSTHIS
        editButton->setWhatsThis(tr2i18n("Click to modify an existing word or regular expression in the list.", 0));
#endif // QT_NO_WHATSTHIS
        editButton->setText(tr2i18n("&Edit", 0));
#ifndef UI_QT_NO_WHATSTHIS
        removeButton->setWhatsThis(tr2i18n("Click to remove a word or regular expression from the list.", 0));
#endif // QT_NO_WHATSTHIS
        removeButton->setText(tr2i18n("&Remove", 0));
        QTableWidgetItem *___qtablewidgetitem = substLView->horizontalHeaderItem(0);
        ___qtablewidgetitem->setText(tr2i18n("Type", 0));
        QTableWidgetItem *___qtablewidgetitem1 = substLView->horizontalHeaderItem(1);
        ___qtablewidgetitem1->setText(tr2i18n("Match Case", 0));
        QTableWidgetItem *___qtablewidgetitem2 = substLView->horizontalHeaderItem(2);
        ___qtablewidgetitem2->setText(tr2i18n("Match", 0));
        QTableWidgetItem *___qtablewidgetitem3 = substLView->horizontalHeaderItem(3);
        ___qtablewidgetitem3->setText(tr2i18n("Replace With", 0));
    } // retranslateUi

};

namespace Ui {
    class StringReplacerConfWidget: public Ui_StringReplacerConfWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // STRINGREPLACERCONFWIDGET_H

