/****************************************************************************
** Meta object code from reading C++ file 'jovie.h'
**
** Created by: The Qt Meta Object Compiler version 63 (Qt 4.8.7)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/jovie-17.04.3/jovie/jovie.h"
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'jovie.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 63
#error "This file was generated using the moc from 4.8.7. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
static const uint qt_meta_data_Jovie[] = {

 // content:
       6,       // revision
       0,       // classname
       0,    0, // classinfo
      72,   14, // methods
       2,  374, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       4,       // signalCount

 // signals: signature, parameters, type, tag, flags
       7,    6,    6,    6, 0x05,
      22,    6,    6,    6, 0x05,
      56,   37,    6,    6, 0x05,
     124,   89,    6,    6, 0x05,

 // slots: signature, parameters, type, tag, flags
     161,    6,  156,    6, 0x0a,
     182,    6,  174,    6, 0x0a,
     192,    6,  174,    6, 0x0a,
     226,  210,    6,    6, 0x0a,
     254,    6,  174,    6, 0x0a,
     284,  270,    6,    6, 0x0a,
     317,  310,    6,    6, 0x0a,
     350,    6,  346,    6, 0x0a,
     384,  368,    6,    6, 0x0a,
     408,    6,  174,    6, 0x0a,
     446,  428,    6,    6, 0x0a,
     476,    6,  156,    6, 0x0a,
     502,  490,    6,    6, 0x0a,
     523,    6,  156,    6, 0x0a,
     571,  548,    6,    6, 0x0a,
     603,    6,  156,    6, 0x0a,
     625,    6,  174,    6, 0x0a,
     665,  646,    6,    6, 0x0a,
     696,    6,  174,    6, 0x0a,
     736,  717,    6,    6, 0x0a,
     767,    6,  156,    6, 0x0a,
     801,  785,    6,    6, 0x0a,
     839,  826,  346,    6, 0x0a,
     874,  856,  346,    6, 0x0a,
     899,    6,  346,    6, 0x0a,
     914,    6,    6,    6, 0x0a,
     922,    6,    6,    6, 0x0a,
     931,    6,    6,    6, 0x0a,
     938,    6,    6,    6, 0x0a,
     959,    6,  947,    6, 0x0a,
     982,  975,  947,    6, 0x0a,
    1009,    6,  947,    6, 0x0a,
    1036, 1030,    6,    6, 0x0a,
    1050,    6,  346,    6, 0x0a,
    1064, 1058,    6,    6, 0x0a,
    1078,    6,  346,    6, 0x0a,
    1093, 1086,    6,    6, 0x0a,
    1108,    6,  346,    6, 0x0a,
    1117,  975,    6,    6, 0x0a,
    1151, 1142,    6,    6, 0x0a,
    1182, 1172,    6,    6, 0x0a,
    1200,    6,  346,    6, 0x0a,
    1224, 1212,    6,    6, 0x0a,
    1255, 1248,    6,    6, 0x0a,
    1270,    6,    6,    6, 0x0a,
    1286, 1248,  346,    6, 0x0a,
    1308,    6,  346,    6, 0x0a,
    1333, 1324,  346,    6, 0x0a,
    1350, 1324,  947,    6, 0x0a,
    1369, 1248,  346,    6, 0x0a,
    1397, 1248, 1386,    6, 0x0a,
    1432, 1413,  174,    6, 0x0a,
    1456,    6,  947,    6, 0x0a,
    1473,  310,  174,    6, 0x0a,
    1499,  310,  346,    6, 0x0a,
    1531,  310,  346,    6, 0x0a,
    1563,  310,  947,    6, 0x0a,
    1602, 1588,    6,    6, 0x0a,
    1631, 1248,    6,    6, 0x0a,
    1658, 1649,  346,    6, 0x0a,
    1683,    6,    6,    6, 0x0a,
    1703,    6,    6,    6, 0x0a,
    1715,    6,    6,    6, 0x0a,
    1722,    6,    6,    6, 0x0a,
    1737, 1731,    6,    6, 0x0a,
    1762,   37,    6,    6, 0x08,
    1813,   89,    6,    6, 0x08,
    1865,    6,    6,    6, 0x08,

 // properties: name, type, flags
    1889,  156, 0x01095001,
    1900,  174, 0x0a095001,

       0        // eod
};

static const char qt_meta_stringdata_Jovie[] = {
    "Jovie\0\0kttsdStarted()\0kttsdExiting()\0"
    "appId,jobNum,state\0jobStateChanged(QString,int,int)\0"
    "appId,jobNum,markerType,markerData\0"
    "marker(QString,int,int,QString)\0bool\0"
    "isSpeaking()\0QString\0version()\0"
    "applicationName()\0applicationName\0"
    "setApplicationName(QString)\0defaultTalker()\0"
    "defaultTalker\0setDefaultTalker(QString)\0"
    "talker\0setCurrentTalker(TalkerCode)\0"
    "int\0defaultPriority()\0defaultPriority\0"
    "setDefaultPriority(int)\0sentenceDelimiter()\0"
    "sentenceDelimiter\0setSentenceDelimiter(QString)\0"
    "filteringOn()\0filteringOn\0"
    "setFilteringOn(bool)\0autoConfigureTalkersOn()\0"
    "autoConfigureTalkersOn\0"
    "setAutoConfigureTalkersOn(bool)\0"
    "isApplicationPaused()\0htmlFilterXsltFile()\0"
    "htmlFilterXsltFile\0setHtmlFilterXsltFile(QString)\0"
    "ssmlFilterXsltFile()\0ssmlFilterXsltFile\0"
    "setSsmlFilterXsltFile(QString)\0"
    "isSystemManager()\0isSystemManager\0"
    "setIsSystemManager(bool)\0text,options\0"
    "say(QString,int)\0filename,encoding\0"
    "sayFile(QString,QString)\0sayClipboard()\0"
    "pause()\0resume()\0stop()\0cancel()\0"
    "QStringList\0outputModules()\0module\0"
    "languagesByModule(QString)\0"
    "getPossibleTalkers()\0speed\0setSpeed(int)\0"
    "speed()\0pitch\0setPitch(int)\0pitch()\0"
    "volume\0setVolume(int)\0volume()\0"
    "setOutputModule(QString)\0language\0"
    "setLanguage(QString)\0voiceType\0"
    "setVoiceType(int)\0voiceType()\0punctuation\0"
    "setPunctuationType(int)\0jobNum\0"
    "removeJob(int)\0removeAllJobs()\0"
    "getSentenceCount(int)\0getCurrentJob()\0"
    "priority\0getJobCount(int)\0getJobNumbers(int)\0"
    "getJobState(int)\0QByteArray\0getJobInfo(int)\0"
    "jobNum,sentenceNum\0getJobSentence(int,int)\0"
    "getTalkerCodes()\0talkerToTalkerId(QString)\0"
    "getTalkerCapabilities1(QString)\0"
    "getTalkerCapabilities2(QString)\0"
    "getTalkerVoices(QString)\0jobNum,talker\0"
    "changeJobTalker(int,QString)\0"
    "moveJobLater(int)\0jobNum,n\0"
    "moveRelSentence(int,int)\0showManagerDialog()\0"
    "kttsdExit()\0init()\0reinit()\0appId\0"
    "setCallingAppId(QString)\0"
    "slotJobStateChanged(QString,int,KSpeech::JobState)\0"
    "slotMarker(QString,int,KSpeech::MarkerType,QString)\0"
    "slotFilteringFinished()\0isSpeaking\0"
    "version\0"
};

void Jovie::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Q_ASSERT(staticMetaObject.cast(_o));
        Jovie *_t = static_cast<Jovie *>(_o);
        switch (_id) {
        case 0: _t->kttsdStarted(); break;
        case 1: _t->kttsdExiting(); break;
        case 2: _t->jobStateChanged((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 3: _t->marker((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4]))); break;
        case 4: { bool _r = _t->isSpeaking();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = _r; }  break;
        case 5: { QString _r = _t->version();
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = _r; }  break;
        case 6: { QString _r = _t->applicationName();
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = _r; }  break;
        case 7: _t->setApplicationName((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 8: { QString _r = _t->defaultTalker();
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = _r; }  break;
        case 9: _t->setDefaultTalker((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 10: _t->setCurrentTalker((*reinterpret_cast< const TalkerCode(*)>(_a[1]))); break;
        case 11: { int _r = _t->defaultPriority();
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = _r; }  break;
        case 12: _t->setDefaultPriority((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 13: { QString _r = _t->sentenceDelimiter();
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = _r; }  break;
        case 14: _t->setSentenceDelimiter((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 15: { bool _r = _t->filteringOn();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = _r; }  break;
        case 16: _t->setFilteringOn((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 17: { bool _r = _t->autoConfigureTalkersOn();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = _r; }  break;
        case 18: _t->setAutoConfigureTalkersOn((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 19: { bool _r = _t->isApplicationPaused();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = _r; }  break;
        case 20: { QString _r = _t->htmlFilterXsltFile();
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = _r; }  break;
        case 21: _t->setHtmlFilterXsltFile((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 22: { QString _r = _t->ssmlFilterXsltFile();
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = _r; }  break;
        case 23: _t->setSsmlFilterXsltFile((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 24: { bool _r = _t->isSystemManager();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = _r; }  break;
        case 25: _t->setIsSystemManager((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 26: { int _r = _t->say((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = _r; }  break;
        case 27: { int _r = _t->sayFile((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = _r; }  break;
        case 28: { int _r = _t->sayClipboard();
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = _r; }  break;
        case 29: _t->pause(); break;
        case 30: _t->resume(); break;
        case 31: _t->stop(); break;
        case 32: _t->cancel(); break;
        case 33: { QStringList _r = _t->outputModules();
            if (_a[0]) *reinterpret_cast< QStringList*>(_a[0]) = _r; }  break;
        case 34: { QStringList _r = _t->languagesByModule((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QStringList*>(_a[0]) = _r; }  break;
        case 35: { QStringList _r = _t->getPossibleTalkers();
            if (_a[0]) *reinterpret_cast< QStringList*>(_a[0]) = _r; }  break;
        case 36: _t->setSpeed((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 37: { int _r = _t->speed();
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = _r; }  break;
        case 38: _t->setPitch((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 39: { int _r = _t->pitch();
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = _r; }  break;
        case 40: _t->setVolume((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 41: { int _r = _t->volume();
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = _r; }  break;
        case 42: _t->setOutputModule((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 43: _t->setLanguage((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 44: _t->setVoiceType((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 45: { int _r = _t->voiceType();
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = _r; }  break;
        case 46: _t->setPunctuationType((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 47: _t->removeJob((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 48: _t->removeAllJobs(); break;
        case 49: { int _r = _t->getSentenceCount((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = _r; }  break;
        case 50: { int _r = _t->getCurrentJob();
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = _r; }  break;
        case 51: { int _r = _t->getJobCount((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = _r; }  break;
        case 52: { QStringList _r = _t->getJobNumbers((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QStringList*>(_a[0]) = _r; }  break;
        case 53: { int _r = _t->getJobState((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = _r; }  break;
        case 54: { QByteArray _r = _t->getJobInfo((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QByteArray*>(_a[0]) = _r; }  break;
        case 55: { QString _r = _t->getJobSentence((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = _r; }  break;
        case 56: { QStringList _r = _t->getTalkerCodes();
            if (_a[0]) *reinterpret_cast< QStringList*>(_a[0]) = _r; }  break;
        case 57: { QString _r = _t->talkerToTalkerId((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = _r; }  break;
        case 58: { int _r = _t->getTalkerCapabilities1((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = _r; }  break;
        case 59: { int _r = _t->getTalkerCapabilities2((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = _r; }  break;
        case 60: { QStringList _r = _t->getTalkerVoices((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QStringList*>(_a[0]) = _r; }  break;
        case 61: _t->changeJobTalker((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 62: _t->moveJobLater((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 63: { int _r = _t->moveRelSentence((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = _r; }  break;
        case 64: _t->showManagerDialog(); break;
        case 65: _t->kttsdExit(); break;
        case 66: _t->init(); break;
        case 67: _t->reinit(); break;
        case 68: _t->setCallingAppId((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 69: _t->slotJobStateChanged((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< KSpeech::JobState(*)>(_a[3]))); break;
        case 70: _t->slotMarker((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< KSpeech::MarkerType(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4]))); break;
        case 71: _t->slotFilteringFinished(); break;
        default: ;
        }
    }
}

const QMetaObjectExtraData Jovie::staticMetaObjectExtraData = {
    0,  qt_static_metacall 
};

const QMetaObject Jovie::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_Jovie,
      qt_meta_data_Jovie, &staticMetaObjectExtraData }
};

#ifdef Q_NO_DATA_RELOCATION
const QMetaObject &Jovie::getStaticMetaObject() { return staticMetaObject; }
#endif //Q_NO_DATA_RELOCATION

const QMetaObject *Jovie::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->metaObject : &staticMetaObject;
}

void *Jovie::qt_metacast(const char *_clname)
{
    if (!_clname) return 0;
    if (!strcmp(_clname, qt_meta_stringdata_Jovie))
        return static_cast<void*>(const_cast< Jovie*>(this));
    return QObject::qt_metacast(_clname);
}

int Jovie::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 72)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 72;
    }
#ifndef QT_NO_PROPERTIES
      else if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< bool*>(_v) = isSpeaking(); break;
        case 1: *reinterpret_cast< QString*>(_v) = version(); break;
        }
        _id -= 2;
    } else if (_c == QMetaObject::WriteProperty) {
        _id -= 2;
    } else if (_c == QMetaObject::ResetProperty) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 2;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void Jovie::kttsdStarted()
{
    QMetaObject::activate(this, &staticMetaObject, 0, 0);
}

// SIGNAL 1
void Jovie::kttsdExiting()
{
    QMetaObject::activate(this, &staticMetaObject, 1, 0);
}

// SIGNAL 2
void Jovie::jobStateChanged(const QString & _t1, int _t2, int _t3)
{
    void *_a[] = { 0, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void Jovie::marker(const QString & _t1, int _t2, int _t3, const QString & _t4)
{
    void *_a[] = { 0, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)), const_cast<void*>(reinterpret_cast<const void*>(&_t4)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}
QT_END_MOC_NAMESPACE
