#include <kdialog.h>
#include <klocale.h>

/********************************************************************************
** Form generated from reading UI file 'talkerwidget.ui'
**
** Created by: Qt User Interface Compiler version 4.8.7
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TALKERWIDGET_H
#define UI_TALKERWIDGET_H

#include <QtCore/QVariant>
#include <QtGui/QAction>
#include <QtGui/QApplication>
#include <QtGui/QButtonGroup>
#include <QtGui/QFormLayout>
#include <QtGui/QHBoxLayout>
#include <QtGui/QHeaderView>
#include <QtGui/QLabel>
#include <QtGui/QSlider>
#include <QtGui/QSpacerItem>
#include <QtGui/QTableWidget>
#include <QtGui/QWidget>
#include "kcombobox.h"
#include "klineedit.h"
#include "knuminput.h"

QT_BEGIN_NAMESPACE

class Ui_TalkerWidget
{
public:
    QFormLayout *formLayout;
    QLabel *nameLabel;
    KLineEdit *nameEdit;
    QTableWidget *AvailableTalkersTable;
    QHBoxLayout *horizontalLayout_6;
    QHBoxLayout *horizontalLayout_5;
    QLabel *label_2;
    KComboBox *voiceComboBox;
    QSpacerItem *horizontalSpacer;
    QHBoxLayout *horizontalLayout_4;
    QLabel *label;
    KComboBox *punctuationComboBox;
    QLabel *label_3;
    QHBoxLayout *horizontalLayout;
    QSlider *speedSlider;
    KIntSpinBox *speedSpinBox;
    QLabel *label_4;
    QHBoxLayout *horizontalLayout_2;
    QSlider *pitchSlider;
    KIntSpinBox *pitchSpinBox;
    QLabel *label_5;
    QHBoxLayout *horizontalLayout_3;
    QSlider *volumeSlider;
    KIntSpinBox *volumeSpinBox;

    void setupUi(QWidget *TalkerWidget)
    {
        if (TalkerWidget->objectName().isEmpty())
            TalkerWidget->setObjectName(QString::fromUtf8("TalkerWidget"));
        TalkerWidget->resize(518, 395);
        formLayout = new QFormLayout(TalkerWidget);
        formLayout->setObjectName(QString::fromUtf8("formLayout"));
        nameLabel = new QLabel(TalkerWidget);
        nameLabel->setObjectName(QString::fromUtf8("nameLabel"));

        formLayout->setWidget(0, QFormLayout::LabelRole, nameLabel);

        nameEdit = new KLineEdit(TalkerWidget);
        nameEdit->setObjectName(QString::fromUtf8("nameEdit"));

        formLayout->setWidget(0, QFormLayout::FieldRole, nameEdit);

        AvailableTalkersTable = new QTableWidget(TalkerWidget);
        if (AvailableTalkersTable->columnCount() < 3)
            AvailableTalkersTable->setColumnCount(3);
        QTableWidgetItem *__qtablewidgetitem = new QTableWidgetItem();
        AvailableTalkersTable->setHorizontalHeaderItem(0, __qtablewidgetitem);
        QTableWidgetItem *__qtablewidgetitem1 = new QTableWidgetItem();
        AvailableTalkersTable->setHorizontalHeaderItem(1, __qtablewidgetitem1);
        QTableWidgetItem *__qtablewidgetitem2 = new QTableWidgetItem();
        AvailableTalkersTable->setHorizontalHeaderItem(2, __qtablewidgetitem2);
        AvailableTalkersTable->setObjectName(QString::fromUtf8("AvailableTalkersTable"));
        AvailableTalkersTable->setEditTriggers(QAbstractItemView::NoEditTriggers);
        AvailableTalkersTable->setTabKeyNavigation(false);
        AvailableTalkersTable->setAlternatingRowColors(true);
        AvailableTalkersTable->setSelectionMode(QAbstractItemView::SingleSelection);
        AvailableTalkersTable->setSelectionBehavior(QAbstractItemView::SelectRows);
        AvailableTalkersTable->setHorizontalScrollMode(QAbstractItemView::ScrollPerPixel);
        AvailableTalkersTable->setSortingEnabled(false);
        AvailableTalkersTable->horizontalHeader()->setVisible(true);
        AvailableTalkersTable->horizontalHeader()->setCascadingSectionResizes(false);
        AvailableTalkersTable->horizontalHeader()->setStretchLastSection(true);
        AvailableTalkersTable->verticalHeader()->setVisible(false);

        formLayout->setWidget(1, QFormLayout::SpanningRole, AvailableTalkersTable);

        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setObjectName(QString::fromUtf8("horizontalLayout_6"));
        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName(QString::fromUtf8("horizontalLayout_5"));
        label_2 = new QLabel(TalkerWidget);
        label_2->setObjectName(QString::fromUtf8("label_2"));

        horizontalLayout_5->addWidget(label_2);

        voiceComboBox = new KComboBox(TalkerWidget);
        voiceComboBox->setObjectName(QString::fromUtf8("voiceComboBox"));
        QSizePolicy sizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(voiceComboBox->sizePolicy().hasHeightForWidth());
        voiceComboBox->setSizePolicy(sizePolicy);

        horizontalLayout_5->addWidget(voiceComboBox);


        horizontalLayout_6->addLayout(horizontalLayout_5);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_6->addItem(horizontalSpacer);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName(QString::fromUtf8("horizontalLayout_4"));
        label = new QLabel(TalkerWidget);
        label->setObjectName(QString::fromUtf8("label"));

        horizontalLayout_4->addWidget(label);

        punctuationComboBox = new KComboBox(TalkerWidget);
        punctuationComboBox->setObjectName(QString::fromUtf8("punctuationComboBox"));

        horizontalLayout_4->addWidget(punctuationComboBox);


        horizontalLayout_6->addLayout(horizontalLayout_4);


        formLayout->setLayout(2, QFormLayout::SpanningRole, horizontalLayout_6);

        label_3 = new QLabel(TalkerWidget);
        label_3->setObjectName(QString::fromUtf8("label_3"));

        formLayout->setWidget(3, QFormLayout::LabelRole, label_3);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        speedSlider = new QSlider(TalkerWidget);
        speedSlider->setObjectName(QString::fromUtf8("speedSlider"));
        speedSlider->setMinimum(-100);
        speedSlider->setMaximum(100);
        speedSlider->setSingleStep(10);
        speedSlider->setPageStep(20);
        speedSlider->setOrientation(Qt::Horizontal);
        speedSlider->setTickPosition(QSlider::TicksAbove);

        horizontalLayout->addWidget(speedSlider);

        speedSpinBox = new KIntSpinBox(TalkerWidget);
        speedSpinBox->setObjectName(QString::fromUtf8("speedSpinBox"));
        speedSpinBox->setMinimum(-100);
        speedSpinBox->setMaximum(100);

        horizontalLayout->addWidget(speedSpinBox);


        formLayout->setLayout(3, QFormLayout::FieldRole, horizontalLayout);

        label_4 = new QLabel(TalkerWidget);
        label_4->setObjectName(QString::fromUtf8("label_4"));

        formLayout->setWidget(4, QFormLayout::LabelRole, label_4);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QString::fromUtf8("horizontalLayout_2"));
        pitchSlider = new QSlider(TalkerWidget);
        pitchSlider->setObjectName(QString::fromUtf8("pitchSlider"));
        pitchSlider->setMinimum(-100);
        pitchSlider->setMaximum(100);
        pitchSlider->setSingleStep(10);
        pitchSlider->setPageStep(20);
        pitchSlider->setOrientation(Qt::Horizontal);
        pitchSlider->setTickPosition(QSlider::TicksAbove);

        horizontalLayout_2->addWidget(pitchSlider);

        pitchSpinBox = new KIntSpinBox(TalkerWidget);
        pitchSpinBox->setObjectName(QString::fromUtf8("pitchSpinBox"));
        pitchSpinBox->setMinimum(-100);
        pitchSpinBox->setMaximum(100);

        horizontalLayout_2->addWidget(pitchSpinBox);


        formLayout->setLayout(4, QFormLayout::FieldRole, horizontalLayout_2);

        label_5 = new QLabel(TalkerWidget);
        label_5->setObjectName(QString::fromUtf8("label_5"));

        formLayout->setWidget(5, QFormLayout::LabelRole, label_5);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName(QString::fromUtf8("horizontalLayout_3"));
        volumeSlider = new QSlider(TalkerWidget);
        volumeSlider->setObjectName(QString::fromUtf8("volumeSlider"));
        volumeSlider->setMinimum(-100);
        volumeSlider->setMaximum(100);
        volumeSlider->setSingleStep(10);
        volumeSlider->setPageStep(20);
        volumeSlider->setOrientation(Qt::Horizontal);
        volumeSlider->setTickPosition(QSlider::TicksAbove);

        horizontalLayout_3->addWidget(volumeSlider);

        volumeSpinBox = new KIntSpinBox(TalkerWidget);
        volumeSpinBox->setObjectName(QString::fromUtf8("volumeSpinBox"));
        volumeSpinBox->setMinimum(-100);
        volumeSpinBox->setMaximum(100);

        horizontalLayout_3->addWidget(volumeSpinBox);


        formLayout->setLayout(5, QFormLayout::FieldRole, horizontalLayout_3);

#ifndef UI_QT_NO_SHORTCUT
        nameLabel->setBuddy(nameEdit);
        label_2->setBuddy(voiceComboBox);
        label->setBuddy(punctuationComboBox);
        label_3->setBuddy(speedSlider);
        label_4->setBuddy(pitchSlider);
        label_5->setBuddy(volumeSlider);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(nameEdit, AvailableTalkersTable);
        QWidget::setTabOrder(AvailableTalkersTable, speedSlider);
        QWidget::setTabOrder(speedSlider, speedSpinBox);
        QWidget::setTabOrder(speedSpinBox, pitchSlider);
        QWidget::setTabOrder(pitchSlider, pitchSpinBox);
        QWidget::setTabOrder(pitchSpinBox, volumeSlider);
        QWidget::setTabOrder(volumeSlider, volumeSpinBox);

        retranslateUi(TalkerWidget);
        QObject::connect(pitchSlider, SIGNAL(valueChanged(int)), pitchSpinBox, SLOT(setValue(int)));
        QObject::connect(pitchSpinBox, SIGNAL(valueChanged(int)), pitchSlider, SLOT(setValue(int)));
        QObject::connect(volumeSlider, SIGNAL(valueChanged(int)), volumeSpinBox, SLOT(setValue(int)));
        QObject::connect(volumeSpinBox, SIGNAL(valueChanged(int)), volumeSlider, SLOT(setValue(int)));
        QObject::connect(speedSlider, SIGNAL(valueChanged(int)), speedSpinBox, SLOT(setValue(int)));
        QObject::connect(speedSpinBox, SIGNAL(valueChanged(int)), speedSlider, SLOT(setValue(int)));

        punctuationComboBox->setCurrentIndex(1);


        QMetaObject::connectSlotsByName(TalkerWidget);
    } // setupUi

    void retranslateUi(QWidget *TalkerWidget)
    {
        nameLabel->setText(tr2i18n("&Name", 0));
        QTableWidgetItem *___qtablewidgetitem = AvailableTalkersTable->horizontalHeaderItem(0);
        ___qtablewidgetitem->setText(tr2i18n("Language", 0));
        QTableWidgetItem *___qtablewidgetitem1 = AvailableTalkersTable->horizontalHeaderItem(1);
        ___qtablewidgetitem1->setText(tr2i18n("Synthesizer", 0));
        QTableWidgetItem *___qtablewidgetitem2 = AvailableTalkersTable->horizontalHeaderItem(2);
        ___qtablewidgetitem2->setText(tr2i18n("Voice Name", 0));
        label_2->setText(tr2i18n("Voice &Type", 0));
        voiceComboBox->clear();
        voiceComboBox->insertItems(0, QStringList()
         << tr2i18n("Male 1", 0)
         << tr2i18n("Male 2", 0)
         << tr2i18n("Male 3", 0)
         << tr2i18n("Female 1", 0)
         << tr2i18n("Female 2", 0)
         << tr2i18n("Female 3", 0)
         << tr2i18n("Male Child", 0)
         << tr2i18n("Female Child", 0)
        );
        label->setText(tr2i18n("Punctuation", 0));
        punctuationComboBox->clear();
        punctuationComboBox->insertItems(0, QStringList()
         << tr2i18n("All", 0)
         << tr2i18n("None", 0)
         << tr2i18n("Some", 0)
        );
#ifndef UI_QT_NO_TOOLTIP
        punctuationComboBox->setToolTip(tr2i18n("<html><head/><body><p><span style=\" font-weight:600; font-style:italic; text-decoration: underline;\">All</span> means speak all punctuation characters.</p><p><span style=\" font-weight:600; font-style:italic; text-decoration: underline;\">None</span> means speak no punctuation characters.</p><p><span style=\" font-weight:600; font-style:italic; text-decoration: underline;\">Some</span> means speak only punctuation characters given in the speech-dispatcher configuration.</p></body></html>", 0));
#endif // QT_NO_TOOLTIP
        label_3->setText(tr2i18n("&Speed", 0));
        label_4->setText(tr2i18n("&Pitch", 0));
        label_5->setText(tr2i18n("&Volume", 0));
        Q_UNUSED(TalkerWidget);
    } // retranslateUi

};

namespace Ui {
    class TalkerWidget: public Ui_TalkerWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // TALKERWIDGET_H

