#include <kdialog.h>
#include <klocale.h>

/*
Widget for configuring Talker Chooser Filter for KTTSD.
*/

/********************************************************************************
** Form generated from reading UI file 'talkerchooserconfwidget.ui'
**
** Created by: Qt User Interface Compiler version 4.8.7
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TALKERCHOOSERCONFWIDGET_H
#define UI_TALKERCHOOSERCONFWIDGET_H

#include <QtCore/QVariant>
#include <QtGui/QAction>
#include <QtGui/QApplication>
#include <QtGui/QButtonGroup>
#include <QtGui/QGridLayout>
#include <QtGui/QGroupBox>
#include <QtGui/QHBoxLayout>
#include <QtGui/QHeaderView>
#include <QtGui/QLabel>
#include <QtGui/QVBoxLayout>
#include <QtGui/QWidget>
#include "klineedit.h"
#include "kpushbutton.h"

QT_BEGIN_NAMESPACE

class Ui_TalkerChooserConfWidget
{
public:
    QGridLayout *gridLayout;
    QHBoxLayout *hboxLayout;
    QLabel *nameLabel;
    KLineEdit *nameLineEdit;
    QGroupBox *applyGroupBox;
    QGridLayout *gridLayout1;
    QVBoxLayout *vboxLayout;
    QLabel *reLabel;
    QLabel *appIdLabel;
    QVBoxLayout *vboxLayout1;
    QHBoxLayout *hboxLayout1;
    KLineEdit *reLineEdit;
    KPushButton *reEditorButton;
    KLineEdit *appIdLineEdit;
    QHBoxLayout *hboxLayout2;
    QLabel *talkerLabel;
    KLineEdit *talkerLineEdit;
    KPushButton *talkerButton;
    QHBoxLayout *hboxLayout3;
    KPushButton *loadButton;
    KPushButton *saveButton;
    KPushButton *clearButton;

    void setupUi(QWidget *TalkerChooserConfWidget)
    {
        if (TalkerChooserConfWidget->objectName().isEmpty())
            TalkerChooserConfWidget->setObjectName(QString::fromUtf8("TalkerChooserConfWidget"));
        TalkerChooserConfWidget->resize(547, 240);
        gridLayout = new QGridLayout(TalkerChooserConfWidget);
#ifndef UI_Q_OS_MAC
        gridLayout->setSpacing(6);
#endif
        gridLayout->setContentsMargins(11, 11, 11, 11);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        hboxLayout = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        hboxLayout->setContentsMargins(0, 0, 0, 0);
#endif
        hboxLayout->setObjectName(QString::fromUtf8("hboxLayout"));
        nameLabel = new QLabel(TalkerChooserConfWidget);
        nameLabel->setObjectName(QString::fromUtf8("nameLabel"));
        nameLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        hboxLayout->addWidget(nameLabel);

        nameLineEdit = new KLineEdit(TalkerChooserConfWidget);
        nameLineEdit->setObjectName(QString::fromUtf8("nameLineEdit"));

        hboxLayout->addWidget(nameLineEdit);


        gridLayout->addLayout(hboxLayout, 0, 0, 1, 1);

        applyGroupBox = new QGroupBox(TalkerChooserConfWidget);
        applyGroupBox->setObjectName(QString::fromUtf8("applyGroupBox"));
        gridLayout1 = new QGridLayout(applyGroupBox);
#ifndef UI_Q_OS_MAC
        gridLayout1->setSpacing(6);
#endif
        gridLayout1->setContentsMargins(11, 11, 11, 11);
        gridLayout1->setObjectName(QString::fromUtf8("gridLayout1"));
        vboxLayout = new QVBoxLayout();
#ifndef UI_Q_OS_MAC
        vboxLayout->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        vboxLayout->setContentsMargins(0, 0, 0, 0);
#endif
        vboxLayout->setObjectName(QString::fromUtf8("vboxLayout"));
        reLabel = new QLabel(applyGroupBox);
        reLabel->setObjectName(QString::fromUtf8("reLabel"));
        reLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        vboxLayout->addWidget(reLabel);

        appIdLabel = new QLabel(applyGroupBox);
        appIdLabel->setObjectName(QString::fromUtf8("appIdLabel"));
        appIdLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        vboxLayout->addWidget(appIdLabel);


        gridLayout1->addLayout(vboxLayout, 0, 0, 1, 1);

        vboxLayout1 = new QVBoxLayout();
#ifndef UI_Q_OS_MAC
        vboxLayout1->setSpacing(6);
#endif
        vboxLayout1->setContentsMargins(0, 0, 0, 0);
        vboxLayout1->setObjectName(QString::fromUtf8("vboxLayout1"));
        hboxLayout1 = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout1->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        hboxLayout1->setContentsMargins(0, 0, 0, 0);
#endif
        hboxLayout1->setObjectName(QString::fromUtf8("hboxLayout1"));
        reLineEdit = new KLineEdit(applyGroupBox);
        reLineEdit->setObjectName(QString::fromUtf8("reLineEdit"));

        hboxLayout1->addWidget(reLineEdit);

        reEditorButton = new KPushButton(applyGroupBox);
        reEditorButton->setObjectName(QString::fromUtf8("reEditorButton"));

        hboxLayout1->addWidget(reEditorButton);


        vboxLayout1->addLayout(hboxLayout1);

        appIdLineEdit = new KLineEdit(applyGroupBox);
        appIdLineEdit->setObjectName(QString::fromUtf8("appIdLineEdit"));

        vboxLayout1->addWidget(appIdLineEdit);


        gridLayout1->addLayout(vboxLayout1, 0, 1, 1, 1);


        gridLayout->addWidget(applyGroupBox, 1, 0, 1, 1);

        hboxLayout2 = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout2->setSpacing(6);
#endif
        hboxLayout2->setContentsMargins(0, 0, 0, 0);
        hboxLayout2->setObjectName(QString::fromUtf8("hboxLayout2"));
        talkerLabel = new QLabel(TalkerChooserConfWidget);
        talkerLabel->setObjectName(QString::fromUtf8("talkerLabel"));
        QSizePolicy sizePolicy(static_cast<QSizePolicy::Policy>(0), static_cast<QSizePolicy::Policy>(5));
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(talkerLabel->sizePolicy().hasHeightForWidth());
        talkerLabel->setSizePolicy(sizePolicy);

        hboxLayout2->addWidget(talkerLabel);

        talkerLineEdit = new KLineEdit(TalkerChooserConfWidget);
        talkerLineEdit->setObjectName(QString::fromUtf8("talkerLineEdit"));
        talkerLineEdit->setEnabled(false);

        hboxLayout2->addWidget(talkerLineEdit);

        talkerButton = new KPushButton(TalkerChooserConfWidget);
        talkerButton->setObjectName(QString::fromUtf8("talkerButton"));

        hboxLayout2->addWidget(talkerButton);


        gridLayout->addLayout(hboxLayout2, 2, 0, 1, 1);

        hboxLayout3 = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout3->setSpacing(6);
#endif
        hboxLayout3->setContentsMargins(0, 0, 0, 0);
        hboxLayout3->setObjectName(QString::fromUtf8("hboxLayout3"));
        loadButton = new KPushButton(TalkerChooserConfWidget);
        loadButton->setObjectName(QString::fromUtf8("loadButton"));
        QSizePolicy sizePolicy1(static_cast<QSizePolicy::Policy>(1), static_cast<QSizePolicy::Policy>(0));
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(loadButton->sizePolicy().hasHeightForWidth());
        loadButton->setSizePolicy(sizePolicy1);

        hboxLayout3->addWidget(loadButton);

        saveButton = new KPushButton(TalkerChooserConfWidget);
        saveButton->setObjectName(QString::fromUtf8("saveButton"));
        sizePolicy1.setHeightForWidth(saveButton->sizePolicy().hasHeightForWidth());
        saveButton->setSizePolicy(sizePolicy1);

        hboxLayout3->addWidget(saveButton);

        clearButton = new KPushButton(TalkerChooserConfWidget);
        clearButton->setObjectName(QString::fromUtf8("clearButton"));
        sizePolicy1.setHeightForWidth(clearButton->sizePolicy().hasHeightForWidth());
        clearButton->setSizePolicy(sizePolicy1);

        hboxLayout3->addWidget(clearButton);


        gridLayout->addLayout(hboxLayout3, 3, 0, 1, 1);

#ifndef UI_QT_NO_SHORTCUT
        nameLabel->setBuddy(nameLineEdit);
        reLabel->setBuddy(reLineEdit);
        appIdLabel->setBuddy(appIdLineEdit);
        talkerLabel->setBuddy(talkerLineEdit);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(nameLineEdit, reLineEdit);
        QWidget::setTabOrder(reLineEdit, reEditorButton);
        QWidget::setTabOrder(reEditorButton, appIdLineEdit);

        retranslateUi(TalkerChooserConfWidget);

        QMetaObject::connectSlotsByName(TalkerChooserConfWidget);
    } // setupUi

    void retranslateUi(QWidget *TalkerChooserConfWidget)
    {
        TalkerChooserConfWidget->setWindowTitle(tr2i18n("Configure Talker Chooser", 0));
#ifndef UI_QT_NO_WHATSTHIS
        nameLabel->setWhatsThis(tr2i18n("Enter any name you like for this filter.", "What's this text"));
#endif // QT_NO_WHATSTHIS
        nameLabel->setText(tr2i18n("&Name:", 0));
#ifndef UI_QT_NO_WHATSTHIS
        nameLineEdit->setWhatsThis(tr2i18n("Enter any name you like for this filter.", 0));
#endif // QT_NO_WHATSTHIS
#ifndef UI_QT_NO_WHATSTHIS
        applyGroupBox->setWhatsThis(tr2i18n("These settings determines when the filter is applied to text.", 0));
#endif // QT_NO_WHATSTHIS
        applyGroupBox->setTitle(tr2i18n("&Apply This Filter When", 0));
#ifndef UI_QT_NO_WHATSTHIS
        reLabel->setWhatsThis(tr2i18n("This filter is applied to text jobs of the specified language.  You may select more than one language by clicking the browse button and Ctrl-clicking on more than one in the list.  If blank, the filter applies to all text jobs of any language.", "What's this text"));
#endif // QT_NO_WHATSTHIS
        reLabel->setText(tr2i18n("Te&xt contains:", 0));
#ifndef UI_QT_NO_WHATSTHIS
        appIdLabel->setWhatsThis(tr2i18n("Enter a D-Bus Application ID.  This filter will only apply to text jobs queued by that application.  You may enter more than one ID separated by commas.  If blank, this filter applies to text jobs queued by all applications.  Tip: Use kdcop from the command line to get the Application IDs of running applications.  Example: \"konversation, kvirc,ksirc,kopete\"", 0));
#endif // QT_NO_WHATSTHIS
        appIdLabel->setText(tr2i18n("Application &ID contains:", 0));
#ifndef UI_QT_NO_WHATSTHIS
        reLineEdit->setWhatsThis(tr2i18n("This filter is applied to text jobs of the specified language.  You may select more than one language by clicking the browse button and Ctrl-clicking on more than one in the list.  If blank, the filter applies to all text jobs of any language.", 0));
#endif // QT_NO_WHATSTHIS
#ifndef UI_QT_NO_WHATSTHIS
        reEditorButton->setWhatsThis(tr2i18n("Click to select one or more languages.  This filter will be applied to text jobs of those languages.", 0));
#endif // QT_NO_WHATSTHIS
        reEditorButton->setText(tr2i18n("...", 0));
#ifndef UI_QT_NO_WHATSTHIS
        appIdLineEdit->setWhatsThis(tr2i18n("<qt>Enter a D-Bus Application ID.  This filter will only apply to text jobs queued by that application.  You may enter more than one ID separated by commas.  Use <b>knotify</b> to match all messages sent as KDE notifications.  If blank, this filter applies to text jobs queued by all applications.  Tip: Use kdcop from the command line to get the Application IDs of running applications.  Example: \"konversation, kvirc,ksirc,kopete\"</qt>", 0));
#endif // QT_NO_WHATSTHIS
#ifndef UI_QT_NO_WHATSTHIS
        talkerLabel->setWhatsThis(tr2i18n("The new Talker that will be used when the conditions above are met.  The default Talker is the topmost in the Talkers tab.  Click the button to choose a Talker.", 0));
#endif // QT_NO_WHATSTHIS
        talkerLabel->setText(tr2i18n("&Talker:", 0));
#ifndef UI_QT_NO_WHATSTHIS
        talkerLineEdit->setWhatsThis(tr2i18n("The new Talker that will be used when the conditions above are met.  The default Talker is the topmost in the Talkers tab.  Click the button to choose a Talker.", 0));
#endif // QT_NO_WHATSTHIS
#ifndef UI_QT_NO_WHATSTHIS
        talkerButton->setWhatsThis(tr2i18n("Click to select a Talker.", 0));
#endif // QT_NO_WHATSTHIS
        talkerButton->setText(tr2i18n("...", 0));
#ifndef UI_QT_NO_WHATSTHIS
        loadButton->setWhatsThis(tr2i18n("Click to load a Talker Chooser configuration from a file.", 0));
#endif // QT_NO_WHATSTHIS
        loadButton->setText(tr2i18n("&Load...", 0));
#ifndef UI_QT_NO_WHATSTHIS
        saveButton->setWhatsThis(tr2i18n("Click to save this Talker Chooser to a file.", 0));
#endif // QT_NO_WHATSTHIS
        saveButton->setText(tr2i18n("&Save...", 0));
#ifndef UI_QT_NO_WHATSTHIS
        clearButton->setWhatsThis(tr2i18n("Click to clear everything.", 0));
#endif // QT_NO_WHATSTHIS
        clearButton->setText(tr2i18n("Cl&ear", 0));
    } // retranslateUi

};

namespace Ui {
    class TalkerChooserConfWidget: public Ui_TalkerChooserConfWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // TALKERCHOOSERCONFWIDGET_H

