#include <kdialog.h>
#include <klocale.h>

/********************************************************************************
** Form generated from reading UI file 'kttsjobmgr.ui'
**
** Created by: Qt User Interface Compiler version 4.8.7
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KTTSJOBMGR_H
#define UI_KTTSJOBMGR_H

#include <QtCore/QVariant>
#include <QtGui/QAction>
#include <QtGui/QApplication>
#include <QtGui/QButtonGroup>
#include <QtGui/QGridLayout>
#include <QtGui/QGroupBox>
#include <QtGui/QHBoxLayout>
#include <QtGui/QHeaderView>
#include <QtGui/QVBoxLayout>
#include <QtGui/QWidget>
#include "kpushbutton.h"
#include "talkerwidget.h"

QT_BEGIN_NAMESPACE

class Ui_kttsjobmgr
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBox_2;
    QGridLayout *gridLayout_3;
    QHBoxLayout *horizontalLayout_4;
    KPushButton *stopButton;
    KPushButton *cancelButton;
    KPushButton *pauseButton;
    KPushButton *resumeButton;
    QHBoxLayout *horizontalLayout_3;
    KPushButton *speak_clipboard;
    KPushButton *speak_file;
    TalkerWidget *talkerWidget;

    void setupUi(QWidget *kttsjobmgr)
    {
        if (kttsjobmgr->objectName().isEmpty())
            kttsjobmgr->setObjectName(QString::fromUtf8("kttsjobmgr"));
        kttsjobmgr->resize(480, 299);
        verticalLayout = new QVBoxLayout(kttsjobmgr);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        groupBox_2 = new QGroupBox(kttsjobmgr);
        groupBox_2->setObjectName(QString::fromUtf8("groupBox_2"));
        gridLayout_3 = new QGridLayout(groupBox_2);
        gridLayout_3->setObjectName(QString::fromUtf8("gridLayout_3"));
        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName(QString::fromUtf8("horizontalLayout_4"));
        stopButton = new KPushButton(groupBox_2);
        stopButton->setObjectName(QString::fromUtf8("stopButton"));
        stopButton->setEnabled(true);

        horizontalLayout_4->addWidget(stopButton);

        cancelButton = new KPushButton(groupBox_2);
        cancelButton->setObjectName(QString::fromUtf8("cancelButton"));
        cancelButton->setEnabled(true);

        horizontalLayout_4->addWidget(cancelButton);

        pauseButton = new KPushButton(groupBox_2);
        pauseButton->setObjectName(QString::fromUtf8("pauseButton"));
        pauseButton->setEnabled(true);

        horizontalLayout_4->addWidget(pauseButton);

        resumeButton = new KPushButton(groupBox_2);
        resumeButton->setObjectName(QString::fromUtf8("resumeButton"));
        resumeButton->setEnabled(true);

        horizontalLayout_4->addWidget(resumeButton);


        gridLayout_3->addLayout(horizontalLayout_4, 1, 0, 1, 2);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName(QString::fromUtf8("horizontalLayout_3"));
        speak_clipboard = new KPushButton(groupBox_2);
        speak_clipboard->setObjectName(QString::fromUtf8("speak_clipboard"));

        horizontalLayout_3->addWidget(speak_clipboard);

        speak_file = new KPushButton(groupBox_2);
        speak_file->setObjectName(QString::fromUtf8("speak_file"));

        horizontalLayout_3->addWidget(speak_file);


        gridLayout_3->addLayout(horizontalLayout_3, 2, 0, 1, 2);

        talkerWidget = new TalkerWidget(groupBox_2);
        talkerWidget->setObjectName(QString::fromUtf8("talkerWidget"));
        QSizePolicy sizePolicy(QSizePolicy::Preferred, QSizePolicy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(talkerWidget->sizePolicy().hasHeightForWidth());
        talkerWidget->setSizePolicy(sizePolicy);

        gridLayout_3->addWidget(talkerWidget, 0, 0, 1, 2);


        verticalLayout->addWidget(groupBox_2);


        retranslateUi(kttsjobmgr);

        QMetaObject::connectSlotsByName(kttsjobmgr);
    } // setupUi

    void retranslateUi(QWidget *kttsjobmgr)
    {
        kttsjobmgr->setWindowTitle(tr2i18n("Jobs", 0));
        groupBox_2->setTitle(tr2i18n("Speech Control", 0));
        stopButton->setText(tr2i18n("Stop", 0));
#ifndef UI_QT_NO_WHATSTHIS
        cancelButton->setWhatsThis(tr2i18n("<p>Deletes the job.  If it is currently speaking, it stops speaking.  The next speakable job in the list begins speaking.</p>", 0));
#endif // QT_NO_WHATSTHIS
        cancelButton->setText(tr2i18n("Cancel", 0));
#ifndef UI_QT_NO_WHATSTHIS
        pauseButton->setWhatsThis(tr2i18n("<p>Changes a job to Paused state.  If currently speaking, the job stops speaking. Paused jobs prevent jobs that follow them from speaking, so either click <b>Resume</b> to make the job speakable, or click <b>Later</b> to move it down in the list.</p>", 0));
#endif // QT_NO_WHATSTHIS
        pauseButton->setText(tr2i18n("Pause", 0));
#ifndef UI_QT_NO_WHATSTHIS
        resumeButton->setWhatsThis(tr2i18n("<p>Resumes a paused job or changes a Queued job to Waiting.  If the job is the top speakable job in the list, it begins speaking.</p>", 0));
#endif // QT_NO_WHATSTHIS
        resumeButton->setText(tr2i18n("Resume", 0));
#ifndef UI_QT_NO_WHATSTHIS
        speak_clipboard->setWhatsThis(tr2i18n("<p>Queues the current contents of the clipboard for speaking and sets its state to Waiting.  If the job is the topmost in the list, it begins speaking.  The job will be spoken by the topmost Talker in the <b>Talkers</b> tab.</p>", 0));
#endif // QT_NO_WHATSTHIS
        speak_clipboard->setText(tr2i18n("&Speak Clipboard", 0));
#ifndef UI_QT_NO_WHATSTHIS
        speak_file->setWhatsThis(tr2i18n("<p>Prompts you for a file name and queues the contents of the file for speaking.  You must click the <b>Resume</b> button before the job will be speakable.  The job will be spoken by the topmost Talker in the <b>Talkers</b> tab.</p>", 0));
#endif // QT_NO_WHATSTHIS
        speak_file->setText(tr2i18n("Spea&k File", 0));
    } // retranslateUi

};

namespace Ui {
    class kttsjobmgr: public Ui_kttsjobmgr {};
} // namespace Ui

QT_END_NAMESPACE

#endif // KTTSJOBMGR_H

