/*
 * This file was generated by qdbusxml2cpp version 0.7
 * Command line was: qdbusxml2cpp -m -a kspeechadaptor -i jovie.h -l Jovie /usr/share/dbus-1/interfaces/org.kde.KSpeech.xml
 *
 * qdbusxml2cpp is Copyright (C) 2015 The Qt Company Ltd.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "kspeechadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class KSpeechAdaptor
 */

KSpeechAdaptor::KSpeechAdaptor(Jovie *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

KSpeechAdaptor::~KSpeechAdaptor()
{
    // destructor
}

bool KSpeechAdaptor::isSpeaking() const
{
    // get the value of property isSpeaking
    return qvariant_cast< bool >(parent()->property("isSpeaking"));
}

QString KSpeechAdaptor::version() const
{
    // get the value of property version
    return qvariant_cast< QString >(parent()->property("version"));
}

QString KSpeechAdaptor::applicationName()
{
    // handle method call org.kde.KSpeech.applicationName
    return parent()->applicationName();
}

bool KSpeechAdaptor::autoConfigureTalkersOn()
{
    // handle method call org.kde.KSpeech.autoConfigureTalkersOn
    return parent()->autoConfigureTalkersOn();
}

void KSpeechAdaptor::cancel()
{
    // handle method call org.kde.KSpeech.cancel
    parent()->cancel();
}

void KSpeechAdaptor::changeJobTalker(int jobNum, const QString &talker)
{
    // handle method call org.kde.KSpeech.changeJobTalker
    parent()->changeJobTalker(jobNum, talker);
}

int KSpeechAdaptor::defaultPriority()
{
    // handle method call org.kde.KSpeech.defaultPriority
    return parent()->defaultPriority();
}

QString KSpeechAdaptor::defaultTalker()
{
    // handle method call org.kde.KSpeech.defaultTalker
    return parent()->defaultTalker();
}

bool KSpeechAdaptor::filteringOn()
{
    // handle method call org.kde.KSpeech.filteringOn
    return parent()->filteringOn();
}

int KSpeechAdaptor::getCurrentJob()
{
    // handle method call org.kde.KSpeech.getCurrentJob
    return parent()->getCurrentJob();
}

int KSpeechAdaptor::getJobCount(int priority)
{
    // handle method call org.kde.KSpeech.getJobCount
    return parent()->getJobCount(priority);
}

QByteArray KSpeechAdaptor::getJobInfo(int jobNum)
{
    // handle method call org.kde.KSpeech.getJobInfo
    return parent()->getJobInfo(jobNum);
}

QStringList KSpeechAdaptor::getJobNumbers(int priority)
{
    // handle method call org.kde.KSpeech.getJobNumbers
    return parent()->getJobNumbers(priority);
}

QString KSpeechAdaptor::getJobSentence(int jobNum, int sentenceNum)
{
    // handle method call org.kde.KSpeech.getJobSentence
    return parent()->getJobSentence(jobNum, sentenceNum);
}

int KSpeechAdaptor::getJobState(int jobNum)
{
    // handle method call org.kde.KSpeech.getJobState
    return parent()->getJobState(jobNum);
}

QStringList KSpeechAdaptor::getPossibleTalkers()
{
    // handle method call org.kde.KSpeech.getPossibleTalkers
    return parent()->getPossibleTalkers();
}

int KSpeechAdaptor::getSentenceCount(int jobNum)
{
    // handle method call org.kde.KSpeech.getSentenceCount
    return parent()->getSentenceCount(jobNum);
}

int KSpeechAdaptor::getTalkerCapabilities1(const QString &talker)
{
    // handle method call org.kde.KSpeech.getTalkerCapabilities1
    return parent()->getTalkerCapabilities1(talker);
}

int KSpeechAdaptor::getTalkerCapabilities2(const QString &talker)
{
    // handle method call org.kde.KSpeech.getTalkerCapabilities2
    return parent()->getTalkerCapabilities2(talker);
}

QStringList KSpeechAdaptor::getTalkerCodes()
{
    // handle method call org.kde.KSpeech.getTalkerCodes
    return parent()->getTalkerCodes();
}

QStringList KSpeechAdaptor::getTalkerVoices(const QString &talker)
{
    // handle method call org.kde.KSpeech.getTalkerVoices
    return parent()->getTalkerVoices(talker);
}

QString KSpeechAdaptor::htmlFilterXsltFile()
{
    // handle method call org.kde.KSpeech.htmlFilterXsltFile
    return parent()->htmlFilterXsltFile();
}

bool KSpeechAdaptor::isApplicationPaused()
{
    // handle method call org.kde.KSpeech.isApplicationPaused
    return parent()->isApplicationPaused();
}

bool KSpeechAdaptor::isSystemManager()
{
    // handle method call org.kde.KSpeech.isSystemManager
    return parent()->isSystemManager();
}

void KSpeechAdaptor::kttsdExit()
{
    // handle method call org.kde.KSpeech.kttsdExit
    parent()->kttsdExit();
}

QStringList KSpeechAdaptor::languagesByModule(const QString &module)
{
    // handle method call org.kde.KSpeech.languagesByModule
    return parent()->languagesByModule(module);
}

void KSpeechAdaptor::moveJobLater(int jobNum)
{
    // handle method call org.kde.KSpeech.moveJobLater
    parent()->moveJobLater(jobNum);
}

int KSpeechAdaptor::moveRelSentence(int jobNum, int n)
{
    // handle method call org.kde.KSpeech.moveRelSentence
    return parent()->moveRelSentence(jobNum, n);
}

QStringList KSpeechAdaptor::outputModules()
{
    // handle method call org.kde.KSpeech.outputModules
    return parent()->outputModules();
}

void KSpeechAdaptor::pause()
{
    // handle method call org.kde.KSpeech.pause
    parent()->pause();
}

void KSpeechAdaptor::reinit()
{
    // handle method call org.kde.KSpeech.reinit
    parent()->reinit();
}

void KSpeechAdaptor::removeAllJobs()
{
    // handle method call org.kde.KSpeech.removeAllJobs
    parent()->removeAllJobs();
}

void KSpeechAdaptor::removeJob(int jobNum)
{
    // handle method call org.kde.KSpeech.removeJob
    parent()->removeJob(jobNum);
}

void KSpeechAdaptor::resume()
{
    // handle method call org.kde.KSpeech.resume
    parent()->resume();
}

int KSpeechAdaptor::say(const QString &text, int options)
{
    // handle method call org.kde.KSpeech.say
    return parent()->say(text, options);
}

int KSpeechAdaptor::sayClipboard()
{
    // handle method call org.kde.KSpeech.sayClipboard
    return parent()->sayClipboard();
}

int KSpeechAdaptor::sayFile(const QString &filename, const QString &encoding)
{
    // handle method call org.kde.KSpeech.sayFile
    return parent()->sayFile(filename, encoding);
}

QString KSpeechAdaptor::sentenceDelimiter()
{
    // handle method call org.kde.KSpeech.sentenceDelimiter
    return parent()->sentenceDelimiter();
}

void KSpeechAdaptor::setApplicationName(const QString &applicationName)
{
    // handle method call org.kde.KSpeech.setApplicationName
    parent()->setApplicationName(applicationName);
}

void KSpeechAdaptor::setAutoConfigureTalkersOn(bool autoConfigureTalkersOn)
{
    // handle method call org.kde.KSpeech.setAutoConfigureTalkersOn
    parent()->setAutoConfigureTalkersOn(autoConfigureTalkersOn);
}

void KSpeechAdaptor::setDefaultPriority(int defaultPriority)
{
    // handle method call org.kde.KSpeech.setDefaultPriority
    parent()->setDefaultPriority(defaultPriority);
}

void KSpeechAdaptor::setDefaultTalker(const QString &defaultTalker)
{
    // handle method call org.kde.KSpeech.setDefaultTalker
    parent()->setDefaultTalker(defaultTalker);
}

void KSpeechAdaptor::setFilteringOn(bool filteringOn)
{
    // handle method call org.kde.KSpeech.setFilteringOn
    parent()->setFilteringOn(filteringOn);
}

void KSpeechAdaptor::setHtmlFilterXsltFile(const QString &htmlFilterXsltFile)
{
    // handle method call org.kde.KSpeech.setHtmlFilterXsltFile
    parent()->setHtmlFilterXsltFile(htmlFilterXsltFile);
}

void KSpeechAdaptor::setIsSystemManager(bool isSystemManager)
{
    // handle method call org.kde.KSpeech.setIsSystemManager
    parent()->setIsSystemManager(isSystemManager);
}

void KSpeechAdaptor::setLanguage(const QString &language)
{
    // handle method call org.kde.KSpeech.setLanguage
    parent()->setLanguage(language);
}

void KSpeechAdaptor::setOutputModule(const QString &module)
{
    // handle method call org.kde.KSpeech.setOutputModule
    parent()->setOutputModule(module);
}

void KSpeechAdaptor::setPitch(int pitch)
{
    // handle method call org.kde.KSpeech.setPitch
    parent()->setPitch(pitch);
}

void KSpeechAdaptor::setPunctuationType(int punctuation)
{
    // handle method call org.kde.KSpeech.setPunctuationType
    parent()->setPunctuationType(punctuation);
}

void KSpeechAdaptor::setSentenceDelimiter(const QString &sentenceDelimiter)
{
    // handle method call org.kde.KSpeech.setSentenceDelimiter
    parent()->setSentenceDelimiter(sentenceDelimiter);
}

void KSpeechAdaptor::setSpeed(int speed)
{
    // handle method call org.kde.KSpeech.setSpeed
    parent()->setSpeed(speed);
}

void KSpeechAdaptor::setSsmlFilterXsltFile(const QString &ssmlFilterXsltFile)
{
    // handle method call org.kde.KSpeech.setSsmlFilterXsltFile
    parent()->setSsmlFilterXsltFile(ssmlFilterXsltFile);
}

void KSpeechAdaptor::setVoiceType(int voiceType)
{
    // handle method call org.kde.KSpeech.setVoiceType
    parent()->setVoiceType(voiceType);
}

void KSpeechAdaptor::setVolume(int volume)
{
    // handle method call org.kde.KSpeech.setVolume
    parent()->setVolume(volume);
}

void KSpeechAdaptor::showManagerDialog()
{
    // handle method call org.kde.KSpeech.showManagerDialog
    parent()->showManagerDialog();
}

QString KSpeechAdaptor::ssmlFilterXsltFile()
{
    // handle method call org.kde.KSpeech.ssmlFilterXsltFile
    return parent()->ssmlFilterXsltFile();
}

void KSpeechAdaptor::stop()
{
    // handle method call org.kde.KSpeech.stop
    parent()->stop();
}

QString KSpeechAdaptor::talkerToTalkerId(const QString &talker)
{
    // handle method call org.kde.KSpeech.talkerToTalkerId
    return parent()->talkerToTalkerId(talker);
}


#include "kspeechadaptor.moc"
