#include <kdialog.h>
#include <klocale.h>

/********************************************************************************
** Form generated from reading UI file 'selecttalkerwidget.ui'
**
** Created by: Qt User Interface Compiler version 4.8.7
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SELECTTALKERWIDGET_H
#define UI_SELECTTALKERWIDGET_H

#include <QtCore/QVariant>
#include <QtGui/QAction>
#include <QtGui/QApplication>
#include <QtGui/QButtonGroup>
#include <QtGui/QGridLayout>
#include <QtGui/QGroupBox>
#include <QtGui/QHBoxLayout>
#include <QtGui/QHeaderView>
#include <QtGui/QRadioButton>
#include <QtGui/QTreeView>
#include <QtGui/QWidget>

QT_BEGIN_NAMESPACE

class Ui_SelectTalkerWidget
{
public:
    QGridLayout *gridLayout;
    QGroupBox *groupBox;
    QGridLayout *gridLayout1;
    QHBoxLayout *hboxLayout;
    QTreeView *talkersView;
    QRadioButton *useDefaultRadioButton;
    QRadioButton *useSpecificTalkerRadioButton;

    void setupUi(QWidget *SelectTalkerWidget)
    {
        if (SelectTalkerWidget->objectName().isEmpty())
            SelectTalkerWidget->setObjectName(QString::fromUtf8("SelectTalkerWidget"));
        SelectTalkerWidget->resize(584, 472);
        QSizePolicy sizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(SelectTalkerWidget->sizePolicy().hasHeightForWidth());
        SelectTalkerWidget->setSizePolicy(sizePolicy);
        gridLayout = new QGridLayout(SelectTalkerWidget);
#ifndef UI_Q_OS_MAC
        gridLayout->setSpacing(6);
#endif
        gridLayout->setContentsMargins(8, 8, 8, 8);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        groupBox = new QGroupBox(SelectTalkerWidget);
        groupBox->setObjectName(QString::fromUtf8("groupBox"));
        gridLayout1 = new QGridLayout(groupBox);
#ifndef UI_Q_OS_MAC
        gridLayout1->setSpacing(6);
#endif
        gridLayout1->setContentsMargins(8, 8, 8, 8);
        gridLayout1->setObjectName(QString::fromUtf8("gridLayout1"));
        hboxLayout = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        hboxLayout->setContentsMargins(0, 0, 0, 0);
#endif
        hboxLayout->setObjectName(QString::fromUtf8("hboxLayout"));
        talkersView = new QTreeView(groupBox);
        talkersView->setObjectName(QString::fromUtf8("talkersView"));

        hboxLayout->addWidget(talkersView);


        gridLayout1->addLayout(hboxLayout, 2, 0, 1, 2);

        useDefaultRadioButton = new QRadioButton(groupBox);
        useDefaultRadioButton->setObjectName(QString::fromUtf8("useDefaultRadioButton"));

        gridLayout1->addWidget(useDefaultRadioButton, 0, 0, 1, 2);

        useSpecificTalkerRadioButton = new QRadioButton(groupBox);
        useSpecificTalkerRadioButton->setObjectName(QString::fromUtf8("useSpecificTalkerRadioButton"));

        gridLayout1->addWidget(useSpecificTalkerRadioButton, 1, 0, 1, 2);


        gridLayout->addWidget(groupBox, 0, 0, 1, 1);

        QWidget::setTabOrder(useDefaultRadioButton, useSpecificTalkerRadioButton);
        QWidget::setTabOrder(useSpecificTalkerRadioButton, talkersView);

        retranslateUi(SelectTalkerWidget);

        QMetaObject::connectSlotsByName(SelectTalkerWidget);
    } // setupUi

    void retranslateUi(QWidget *SelectTalkerWidget)
    {
        SelectTalkerWidget->setWindowTitle(tr2i18n("Select Talker", 0));
        groupBox->setTitle(QString());
#ifndef UI_QT_NO_WHATSTHIS
        useDefaultRadioButton->setWhatsThis(tr2i18n("When checked, will use the default Talker, which is the topmost Talker listed in the Talkers tab.", 0));
#endif // QT_NO_WHATSTHIS
        useDefaultRadioButton->setText(tr2i18n("&Use default Talker", 0));
#ifndef UI_QT_NO_WHATSTHIS
        useSpecificTalkerRadioButton->setWhatsThis(tr2i18n("When checked, will use the specific Talker (if it is still configured), otherwise the Talker most closely matching.", 0));
#endif // QT_NO_WHATSTHIS
        useSpecificTalkerRadioButton->setText(tr2i18n("Use specific &Talker", 0));
    } // retranslateUi

};

namespace Ui {
    class SelectTalkerWidget: public Ui_SelectTalkerWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SELECTTALKERWIDGET_H

