#include <kdialog.h>
#include <klocale.h>

/********************************************************************************
** Form generated from reading UI file 'xmltransformerconfwidget.ui'
**
** Created by: Qt User Interface Compiler version 4.8.7
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_XMLTRANSFORMERCONFWIDGET_H
#define UI_XMLTRANSFORMERCONFWIDGET_H

#include <QtCore/QVariant>
#include <QtGui/QAction>
#include <QtGui/QApplication>
#include <QtGui/QButtonGroup>
#include <QtGui/QGridLayout>
#include <QtGui/QGroupBox>
#include <QtGui/QHeaderView>
#include <QtGui/QLabel>
#include <QtGui/QVBoxLayout>
#include <QtGui/QWidget>
#include "klineedit.h"
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_XmlTransformerConfWidget
{
public:
    QGridLayout *gridLayout;
    QVBoxLayout *vboxLayout;
    KLineEdit *nameLineEdit;
    KUrlRequester *xsltPath;
    KUrlRequester *xsltprocPath;
    QVBoxLayout *vboxLayout1;
    QLabel *nameLabel;
    QLabel *xsltLabel;
    QLabel *xsltprocLabel;
    QGroupBox *applyGroupBox;
    QGridLayout *gridLayout1;
    QVBoxLayout *vboxLayout2;
    KLineEdit *rootElementLineEdit;
    KLineEdit *doctypeLineEdit;
    KLineEdit *appIdLineEdit;
    QVBoxLayout *vboxLayout3;
    QLabel *rootElementLabel;
    QLabel *doctypeLabel;
    QLabel *appIdLabel;

    void setupUi(QWidget *XmlTransformerConfWidget)
    {
        if (XmlTransformerConfWidget->objectName().isEmpty())
            XmlTransformerConfWidget->setObjectName(QString::fromUtf8("XmlTransformerConfWidget"));
        XmlTransformerConfWidget->resize(548, 256);
        gridLayout = new QGridLayout(XmlTransformerConfWidget);
#ifndef UI_Q_OS_MAC
        gridLayout->setSpacing(6);
#endif
        gridLayout->setContentsMargins(11, 11, 11, 11);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        vboxLayout = new QVBoxLayout();
#ifndef UI_Q_OS_MAC
        vboxLayout->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        vboxLayout->setContentsMargins(0, 0, 0, 0);
#endif
        vboxLayout->setObjectName(QString::fromUtf8("vboxLayout"));
        nameLineEdit = new KLineEdit(XmlTransformerConfWidget);
        nameLineEdit->setObjectName(QString::fromUtf8("nameLineEdit"));
        QSizePolicy sizePolicy(static_cast<QSizePolicy::Policy>(5), static_cast<QSizePolicy::Policy>(0));
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(nameLineEdit->sizePolicy().hasHeightForWidth());
        nameLineEdit->setSizePolicy(sizePolicy);

        vboxLayout->addWidget(nameLineEdit);

        xsltPath = new KUrlRequester(XmlTransformerConfWidget);
        xsltPath->setObjectName(QString::fromUtf8("xsltPath"));
        sizePolicy.setHeightForWidth(xsltPath->sizePolicy().hasHeightForWidth());
        xsltPath->setSizePolicy(sizePolicy);

        vboxLayout->addWidget(xsltPath);

        xsltprocPath = new KUrlRequester(XmlTransformerConfWidget);
        xsltprocPath->setObjectName(QString::fromUtf8("xsltprocPath"));
        sizePolicy.setHeightForWidth(xsltprocPath->sizePolicy().hasHeightForWidth());
        xsltprocPath->setSizePolicy(sizePolicy);

        vboxLayout->addWidget(xsltprocPath);


        gridLayout->addLayout(vboxLayout, 0, 1, 1, 1);

        vboxLayout1 = new QVBoxLayout();
#ifndef UI_Q_OS_MAC
        vboxLayout1->setSpacing(6);
#endif
        vboxLayout1->setContentsMargins(0, 0, 0, 0);
        vboxLayout1->setObjectName(QString::fromUtf8("vboxLayout1"));
        nameLabel = new QLabel(XmlTransformerConfWidget);
        nameLabel->setObjectName(QString::fromUtf8("nameLabel"));
        nameLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        vboxLayout1->addWidget(nameLabel);

        xsltLabel = new QLabel(XmlTransformerConfWidget);
        xsltLabel->setObjectName(QString::fromUtf8("xsltLabel"));
        xsltLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        vboxLayout1->addWidget(xsltLabel);

        xsltprocLabel = new QLabel(XmlTransformerConfWidget);
        xsltprocLabel->setObjectName(QString::fromUtf8("xsltprocLabel"));
        xsltprocLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        vboxLayout1->addWidget(xsltprocLabel);


        gridLayout->addLayout(vboxLayout1, 0, 0, 1, 1);

        applyGroupBox = new QGroupBox(XmlTransformerConfWidget);
        applyGroupBox->setObjectName(QString::fromUtf8("applyGroupBox"));
        gridLayout1 = new QGridLayout(applyGroupBox);
#ifndef UI_Q_OS_MAC
        gridLayout1->setSpacing(6);
#endif
        gridLayout1->setContentsMargins(11, 11, 11, 11);
        gridLayout1->setObjectName(QString::fromUtf8("gridLayout1"));
        vboxLayout2 = new QVBoxLayout();
#ifndef UI_Q_OS_MAC
        vboxLayout2->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        vboxLayout2->setContentsMargins(0, 0, 0, 0);
#endif
        vboxLayout2->setObjectName(QString::fromUtf8("vboxLayout2"));
        rootElementLineEdit = new KLineEdit(applyGroupBox);
        rootElementLineEdit->setObjectName(QString::fromUtf8("rootElementLineEdit"));
        sizePolicy.setHeightForWidth(rootElementLineEdit->sizePolicy().hasHeightForWidth());
        rootElementLineEdit->setSizePolicy(sizePolicy);

        vboxLayout2->addWidget(rootElementLineEdit);

        doctypeLineEdit = new KLineEdit(applyGroupBox);
        doctypeLineEdit->setObjectName(QString::fromUtf8("doctypeLineEdit"));
        sizePolicy.setHeightForWidth(doctypeLineEdit->sizePolicy().hasHeightForWidth());
        doctypeLineEdit->setSizePolicy(sizePolicy);

        vboxLayout2->addWidget(doctypeLineEdit);

        appIdLineEdit = new KLineEdit(applyGroupBox);
        appIdLineEdit->setObjectName(QString::fromUtf8("appIdLineEdit"));
        sizePolicy.setHeightForWidth(appIdLineEdit->sizePolicy().hasHeightForWidth());
        appIdLineEdit->setSizePolicy(sizePolicy);

        vboxLayout2->addWidget(appIdLineEdit);


        gridLayout1->addLayout(vboxLayout2, 0, 1, 1, 1);

        vboxLayout3 = new QVBoxLayout();
#ifndef UI_Q_OS_MAC
        vboxLayout3->setSpacing(6);
#endif
        vboxLayout3->setContentsMargins(0, 0, 0, 0);
        vboxLayout3->setObjectName(QString::fromUtf8("vboxLayout3"));
        rootElementLabel = new QLabel(applyGroupBox);
        rootElementLabel->setObjectName(QString::fromUtf8("rootElementLabel"));
        rootElementLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        vboxLayout3->addWidget(rootElementLabel);

        doctypeLabel = new QLabel(applyGroupBox);
        doctypeLabel->setObjectName(QString::fromUtf8("doctypeLabel"));
        doctypeLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        vboxLayout3->addWidget(doctypeLabel);

        appIdLabel = new QLabel(applyGroupBox);
        appIdLabel->setObjectName(QString::fromUtf8("appIdLabel"));
        appIdLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        vboxLayout3->addWidget(appIdLabel);


        gridLayout1->addLayout(vboxLayout3, 0, 0, 1, 1);


        gridLayout->addWidget(applyGroupBox, 1, 0, 1, 2);

#ifndef UI_QT_NO_SHORTCUT
        nameLabel->setBuddy(nameLineEdit);
        xsltLabel->setBuddy(xsltPath);
        xsltprocLabel->setBuddy(xsltprocPath);
        rootElementLabel->setBuddy(rootElementLineEdit);
        doctypeLabel->setBuddy(doctypeLineEdit);
        appIdLabel->setBuddy(appIdLineEdit);
#endif // QT_NO_SHORTCUT

        retranslateUi(XmlTransformerConfWidget);

        QMetaObject::connectSlotsByName(XmlTransformerConfWidget);
    } // setupUi

    void retranslateUi(QWidget *XmlTransformerConfWidget)
    {
        XmlTransformerConfWidget->setWindowTitle(tr2i18n("Configure XML Transformer", 0));
#ifndef UI_QT_NO_WHATSTHIS
        nameLineEdit->setWhatsThis(tr2i18n("Enter any descriptive name you like for this filter.", 0));
#endif // QT_NO_WHATSTHIS
#ifndef UI_QT_NO_WHATSTHIS
        xsltPath->setWhatsThis(tr2i18n("Enter the full path to an XML Style Language - Transforms (XSLT) stylesheet file.  XSLT files usually end with extension .xsl.", 0));
#endif // QT_NO_WHATSTHIS
#ifndef UI_QT_NO_WHATSTHIS
        xsltprocPath->setWhatsThis(tr2i18n("Enter the path to the xsltproc executable program.  If it is in the PATH environment variable, just enter \"xsltproc\".", 0));
#endif // QT_NO_WHATSTHIS
#ifndef UI_QT_NO_WHATSTHIS
        nameLabel->setWhatsThis(tr2i18n("Enter any descriptive name you like for this filter.", "What's this text"));
#endif // QT_NO_WHATSTHIS
        nameLabel->setText(tr2i18n("&Name:", 0));
#ifndef UI_QT_NO_WHATSTHIS
        xsltLabel->setWhatsThis(tr2i18n("Enter the full path to an XML Style Language - Transforms (XSLT) stylesheet file.  XSLT files usually end with extension .xsl.", 0));
#endif // QT_NO_WHATSTHIS
        xsltLabel->setText(tr2i18n("&XSLT file:", 0));
#ifndef UI_QT_NO_WHATSTHIS
        xsltprocLabel->setWhatsThis(tr2i18n("Enter the path to the xsltproc executable program.  If it is in the PATH environment variable, just enter \"xsltproc\".", 0));
#endif // QT_NO_WHATSTHIS
        xsltprocLabel->setText(tr2i18n("xsltproc &executable:", 0));
#ifndef UI_QT_NO_WHATSTHIS
        applyGroupBox->setWhatsThis(tr2i18n("These settings determines when the filter is applied to text.", 0));
#endif // QT_NO_WHATSTHIS
        applyGroupBox->setTitle(tr2i18n("Apply This &Filter When", 0));
#ifndef UI_QT_NO_WHATSTHIS
        rootElementLineEdit->setWhatsThis(tr2i18n("This filter will be applied only to text having the specified XML root element.  If blank, applies to all text.  You may enter more than one root element separated by commas.  Example: \"html\".", 0));
#endif // QT_NO_WHATSTHIS
#ifndef UI_QT_NO_WHATSTHIS
        doctypeLineEdit->setWhatsThis(tr2i18n("This filter will be applied only to text having the specified DOCTYPE specification.  If blank, applies to all text.  You may enter more than one DOCTYPE separated by commas.  Example: \"xhtml\".", 0));
#endif // QT_NO_WHATSTHIS
#ifndef UI_QT_NO_WHATSTHIS
        appIdLineEdit->setWhatsThis(tr2i18n("<qt>Enter a D-Bus Application ID.  This filter will only apply to text queued by that application.  You may enter more than one ID separated by commas.  Use <b>knotify</b> to match all messages sent as KDE notifications.  If blank, this filter applies to text queued by all applications.  Tip: Use kdcop from the command line to get the Application IDs of running applications.  Example: \"konversation, kvirc,ksirc,kopete\"</qt>", 0));
#endif // QT_NO_WHATSTHIS
#ifndef UI_QT_NO_WHATSTHIS
        rootElementLabel->setWhatsThis(tr2i18n("This filter will be applied only to text having the specified XML root element.  If blank, applies to all text.  You may enter more than one root element separated by commas.  Example: \"html\".", "What's this text"));
#endif // QT_NO_WHATSTHIS
        rootElementLabel->setText(tr2i18n("&Root element is:", 0));
#ifndef UI_QT_NO_WHATSTHIS
        doctypeLabel->setWhatsThis(tr2i18n("This filter will be applied only to text having the specified DOCTYPE specification.  If blank, applies to all text.  You may enter more than one DOCTYPE separated by commas.  Example: \"xhtml\".", 0));
#endif // QT_NO_WHATSTHIS
        doctypeLabel->setText(tr2i18n("or DOC&TYPE is:", 0));
#ifndef UI_QT_NO_WHATSTHIS
        appIdLabel->setWhatsThis(tr2i18n("<qt>Enter a D-Bus Application ID.  This filter will only apply to text queued by that application.  You may enter more than one ID separated by commas.  Use <b>knotify</b> to match all messages sent as KDE notifications.  If blank, this filter applies to text queued by all applications.  Tip: Use kdcop from the command line to get the Application IDs of running applications.  Example: \"konversation, kvirc,ksirc,kopete\"</qt>", 0));
#endif // QT_NO_WHATSTHIS
        appIdLabel->setText(tr2i18n("and Application &ID contains:", 0));
    } // retranslateUi

};

namespace Ui {
    class XmlTransformerConfWidget: public Ui_XmlTransformerConfWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // XMLTRANSFORMERCONFWIDGET_H

